function [residual, g1, g2] = nonlinearomegaestimate_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                    columns: equations in order of declaration
%                                                    rows: variables in declaration order
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: equations in order of declaration
%                                                       rows: variables in declaration order
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 223, 1);

%
% Model equations
%

T19 = exp(y(39))*exp(y(8))-exp(y(8))*params(2)/params(3);
T20 = log(T19);
T47 = exp(y(78))*exp(y(47))-exp(y(47))*params(57)/params(58);
T48 = log(T47);
T102 = params(5)/params(3);
T108 = exp(y(4))*T102/exp(y(14))/exp(y(4))*exp(y(18));
T117 = exp(y(4))*exp(y(14))*exp(y(5))*params(5)*(1-params(6))/params(3)/exp(y(14))/exp(y(4));
T130 = params(10)/(1+params(10));
T131 = params(163)^T130;
T134 = 1/(1+params(10));
T138 = params(162)^T130;
T140 = exp(y(92));
T146 = T131*exp(y(9))^T134+T138*(T140*exp(y(12)))^T134;
T152 = params(9)/(1+params(9));
T153 = params(164)^T152;
T156 = 1/(1+params(9));
T163 = (params(165)*exp(y(40)))^T152;
T168 = T153*exp(y(10))^T156+T163*exp(y(11))^T156;
T172 = exp(y(8))*params(163)/exp(y(9));
T174 = exp(y(185))*T172^T130;
T176 = exp(y(9))*params(164)/exp(y(10));
T177 = T176^T152;
T183 = exp(y(9))*params(165)*exp(y(40))/exp(y(11));
T184 = T183^T152;
T191 = exp(y(8))*params(162)/T140/exp(y(12));
T194 = T140*exp(y(185))*T191^T130;
T199 = params(168)/(1+params(168));
T200 = params(166)^T199;
T203 = 1/(1+params(168));
T210 = (params(167)*exp(y(42)))^T199;
T215 = T200*exp(y(13))^T203+T210*exp(y(15))^T203;
T219 = exp(y(6))*params(166)/exp(y(13));
T226 = exp(y(6))*params(167)*exp(y(42))/exp(y(15));
T235 = params(18)/(1+params(18));
T236 = params(15)^T235;
T238 = 1/(1+params(18));
T242 = params(19)^T235;
T248 = T236*(exp(y(7))/params(3))^T238+T242*(exp(y(19))*exp(y(88)))^T238;
T254 = params(169)^T130;
T258 = params(170)^T130;
T264 = T254*exp(y(16))^T134+T258*(T140*exp(y(103)))^T134;
T270 = exp(y(17))*params(169)/exp(y(16));
T272 = exp(y(183))*T270^T130;
T275 = params(3)*exp(y(16))*params(15)/exp(y(7));
T276 = T275^T235;
T284 = exp(y(16))*params(19)/exp(y(88))/exp(y(19));
T285 = T284^T235;
T290 = exp(y(17))*params(170)/T140/exp(y(103));
T293 = T140*exp(y(183))*T290^T130;
T296 = exp(y(220));
T313 = exp(y(4))*T102/exp(y(4));
T356 = (exp(y(28))/params(13))^(1-params(35));
T378 = exp(y(20))*params(13)*exp(y(30))*(1-params(35))/exp(y(28));
T525 = params(60)/params(58);
T531 = exp(y(43))*T525/exp(y(53))/exp(y(43))*exp(y(57));
T540 = exp(y(43))*exp(y(53))*exp(y(44))*params(60)*(1-params(61))/params(58)/exp(y(53))/exp(y(43));
T553 = params(65)/(1+params(65));
T554 = params(177)^T553;
T557 = 1/(1+params(65));
T561 = params(176)^T553;
T563 = exp(y(93));
T569 = T554*exp(y(48))^T557+T561*(T563*exp(y(51)))^T557;
T575 = params(64)/(1+params(64));
T576 = params(178)^T575;
T579 = 1/(1+params(64));
T586 = (params(179)*exp(y(79)))^T575;
T591 = T576*exp(y(49))^T579+T586*exp(y(50))^T579;
T595 = exp(y(47))*params(177)/exp(y(48));
T597 = exp(y(184))*T595^T553;
T599 = exp(y(48))*params(178)/exp(y(49));
T600 = T599^T575;
T606 = exp(y(48))*params(179)*exp(y(79))/exp(y(50));
T607 = T606^T575;
T614 = exp(y(47))*params(176)/T563/exp(y(51));
T617 = T563*exp(y(184))*T614^T553;
T622 = params(182)/(1+params(182));
T623 = params(180)^T622;
T626 = 1/(1+params(182));
T633 = (params(181)*exp(y(81)))^T622;
T638 = T623*exp(y(52))^T626+T633*exp(y(54))^T626;
T642 = exp(y(45))*params(180)/exp(y(52));
T649 = exp(y(45))*params(181)*exp(y(81))/exp(y(54));
T658 = params(73)/(1+params(73));
T659 = params(70)^T658;
T661 = 1/(1+params(73));
T665 = params(74)^T658;
T671 = T659*(exp(y(46))/params(58))^T661+T665*(exp(y(58))*exp(y(89)))^T661;
T677 = params(183)^T553;
T681 = params(184)^T553;
T687 = T677*exp(y(55))^T557+T681*(T563*exp(y(102)))^T557;
T693 = exp(y(56))*params(183)/exp(y(55));
T695 = exp(y(182))*T693^T553;
T698 = params(58)*exp(y(55))*params(70)/exp(y(46));
T699 = T698^T658;
T707 = exp(y(55))*params(74)/exp(y(89))/exp(y(58));
T708 = T707^T658;
T713 = exp(y(56))*params(184)/T563/exp(y(102));
T716 = T563*exp(y(182))*T713^T553;
T736 = exp(y(43))*T525/exp(y(43));
T779 = (exp(y(67))/params(68))^(1-params(90));
T801 = exp(y(59))*params(68)*exp(y(69))*(1-params(90))/exp(y(67));
T930 = exp(y(185))*exp(y(82))/exp(y(184));
T931 = exp(y(83))*T930;
T936 = params(3)*T296*T736/exp((-params(111))*y(85))/T296;
T943 = exp(y(184))*1/exp(y(82))/exp(y(185));
T947 = 1/params(171);
T1000 = exp(y(39))*exp(y(114))-params(2)/params(3)*exp(y(114));
T1053 = exp(y(110))*T102/exp(y(120))/exp(y(110))*exp(y(124));
T1058 = exp(y(110))*exp(y(120))*params(5)*(1-params(6))/params(3)*exp(y(111))/exp(y(120))/exp(y(110));
T1076 = T131*exp(y(115))^T134+T138*(T140*exp(y(118)))^T134;
T1087 = T153*exp(y(116))^T156+T163*exp(y(117))^T156;
T1091 = params(163)*exp(y(114))/exp(y(115));
T1093 = exp(y(181))*T1091^T130;
T1095 = params(164)*exp(y(115))/exp(y(116));
T1096 = T1095^T152;
T1102 = params(165)*exp(y(40))*exp(y(115))/exp(y(117));
T1110 = params(162)*exp(y(114))/T140/exp(y(118));
T1113 = T140*exp(y(181))*T1110^T130;
T1123 = T200*exp(y(119))^T203+T210*exp(y(121))^T203;
T1127 = params(166)*exp(y(112))/exp(y(119));
T1134 = params(167)*exp(y(42))*exp(y(112))/exp(y(121));
T1146 = T236*(exp(y(113))/params(3))^T238+T242*(exp(y(88))*exp(y(125)))^T238;
T1158 = T254*exp(y(122))^T134+T258*(T140*exp(y(175)))^T134;
T1164 = params(169)*exp(y(123))/exp(y(122));
T1166 = exp(y(177))*T1164^T130;
T1169 = params(3)*params(15)*exp(y(122))/exp(y(113));
T1170 = T1169^T235;
T1176 = params(19)*exp(y(122))/exp(y(88))/exp(y(125));
T1182 = params(170)*exp(y(123))/T140/exp(y(175));
T1185 = T140*exp(y(177))*T1182^T130;
T1242 = (exp(y(132))/params(13))^(1-params(35));
T1259 = exp(y(126))*params(13)*(1-params(35))*exp(y(134))/exp(y(132));
T1268 = exp(y(78))*exp(y(140))-params(57)/params(58)*exp(y(140));
T1321 = exp(y(136))*T525/exp(y(146))/exp(y(136))*exp(y(150));
T1326 = exp(y(136))*exp(y(146))*params(60)*(1-params(61))/params(58)*exp(y(137))/exp(y(146))/exp(y(136));
T1344 = T554*exp(y(141))^T557+T561*(T563*exp(y(144)))^T557;
T1355 = T576*exp(y(142))^T579+T586*exp(y(143))^T579;
T1359 = params(177)*exp(y(140))/exp(y(141));
T1361 = exp(y(180))*T1359^T553;
T1363 = params(178)*exp(y(141))/exp(y(142));
T1364 = T1363^T575;
T1370 = params(179)*exp(y(79))*exp(y(141))/exp(y(143));
T1378 = params(176)*exp(y(140))/T563/exp(y(144));
T1381 = T563*exp(y(180))*T1378^T553;
T1391 = T623*exp(y(145))^T626+T633*exp(y(147))^T626;
T1395 = params(180)*exp(y(138))/exp(y(145));
T1402 = params(181)*exp(y(81))*exp(y(138))/exp(y(147));
T1414 = T659*(exp(y(139))/params(58))^T661+T665*(exp(y(89))*exp(y(151)))^T661;
T1426 = T677*exp(y(148))^T557+T681*(T563*exp(y(174)))^T557;
T1432 = params(183)*exp(y(149))/exp(y(148));
T1434 = exp(y(176))*T1432^T553;
T1437 = params(58)*params(70)*exp(y(148))/exp(y(139));
T1438 = T1437^T658;
T1444 = params(74)*exp(y(148))/exp(y(89))/exp(y(151));
T1450 = params(184)*exp(y(149))/T563/exp(y(174));
T1453 = T563*exp(y(176))*T1450^T553;
T1482 = T525*exp(y(136))/exp(y(136));
T1510 = (exp(y(158))/params(68))^(1-params(90));
T1527 = exp(y(152))*params(68)*(1-params(90))*exp(y(160))/exp(y(158));
T1548 = exp(y(181))*exp(y(162))/exp(y(180));
T1549 = exp(y(163))*T1548;
T1554 = params(3)*exp(y(123))*T1482/exp((-params(111))*y(165))/exp(y(222));
T1555 = y(165)*T1554;
T1561 = exp(y(180))*1/exp(y(162))/exp(y(181));
T1575 = T296*exp(y(183))*(1+params(135)*exp(y(105)))/(params(135)*exp(y(105)));
T1579 = exp(y(4))*params(5)*params(141)/exp(y(4));
T1582 = y(211)/y(212);
T1584 = (-(1+params(135)*exp(y(105))))/(params(135)*exp(y(105)));
T1585 = T1582^T1584;
T1595 = T1582^(1-(1+params(135)*exp(y(105)))/(params(135)*exp(y(105))));
T1605 = (-1)/(params(135)*exp(y(105)));
T1606 = exp(y(210))^T1605;
T1608 = T1582^T1605;
T1638 = exp(y(221))*exp(y(182))*(1+params(134)*exp(y(104)))/(params(134)*exp(y(104)));
T1642 = exp(y(43))*params(60)*params(139)/exp(y(43));
T1645 = y(217)/y(218);
T1647 = (-(1+params(134)*exp(y(104))))/(params(134)*exp(y(104)));
T1648 = T1645^T1647;
T1658 = T1645^(1-(1+params(134)*exp(y(104)))/(params(134)*exp(y(104))));
T1668 = (-1)/(params(134)*exp(y(104)));
T1669 = exp(y(216))^T1668;
T1671 = T1645^T1668;
T1700 = exp(y(107))*(1+params(137)*exp(y(109)))/(params(137)*exp(y(109)));
T1702 = exp(y(19))*T1700/exp(y(101));
T1707 = exp(y(4))*params(5)*params(145)/params(3)/exp(y(4));
T1708 = T1707/y(212);
T1710 = T1708*y(202);
T1712 = y(201)/y(202);
T1715 = T1712^((-(1+params(137)*exp(y(109))))/(params(137)*exp(y(109))));
T1725 = T1712^(1-(1+params(137)*exp(y(109)))/(params(137)*exp(y(109))));
T1732 = exp(y(200))/exp(y(101));
T1736 = (-1)/(params(137)*exp(y(109)));
T1755 = exp(y(106))*(1+params(136)*exp(y(108)))/(params(136)*exp(y(108)));
T1757 = exp(y(58))*T1755/exp(y(100));
T1762 = exp(y(43))*params(60)*params(143)/params(58)/exp(y(43));
T1763 = T1762/y(218);
T1765 = T1763*y(207);
T1767 = y(206)/y(207);
T1770 = T1767^((-(1+params(136)*exp(y(108))))/(params(136)*exp(y(108))));
T1780 = T1767^(1-(1+params(136)*exp(y(108)))/(params(136)*exp(y(108))));
T1787 = exp(y(205))/exp(y(100));
T1791 = (-1)/(params(136)*exp(y(108)));
T1813 = ((1+y(194))/(1+params(190)))^params(146);
T1817 = (1+y(189))/(1+log(params(172)));
T1819 = T1817^params(149);
T1821 = T296/exp(y(222));
T1823 = T1821^params(151);
T1829 = (1+y(191))/(1+log(params(172))+log(params(39)));
T1831 = T1829^params(152);
T1837 = (1+log(y(202)))/(1+log(params(172))+log(params(3)));
T1839 = T1837^params(147);
T1848 = (1/(1+y(196)))^params(150);
T1851 = (T1848)^(1-params(148));
T1881 = ((1+y(195))/(1+params(191)))^params(153);
T1885 = (1+y(188))/(1+log(params(185)));
T1888 = 1+log(params(185))+(1+log(params(185)))*y(197);
T1889 = (1+y(188))/T1888;
T1891 = T1889^params(154);
T1893 = exp(y(221))/exp(y(223));
T1895 = T1893^params(156);
T1898 = (T1885*T1891*T1895)^(1-params(153));
T1960 = exp(y(185))*T172*getPowerDeriv(T172,T130,1);
T1981 = exp(y(185))*getPowerDeriv(T172,T130,1)*(-(exp(y(9))*exp(y(8))*params(163)))/(exp(y(9))*exp(y(9)));
T1997 = getPowerDeriv(T168,1+params(9),1);
T2026 = (-(getPowerDeriv(T146,1+params(10),1)*T138*T140*exp(y(12))*getPowerDeriv(T140*exp(y(12)),T134,1)));
T2039 = getPowerDeriv(T215,1+params(168),1);
T2086 = exp(y(183))*(-(exp(y(16))*exp(y(17))*params(169)))/(exp(y(16))*exp(y(16)))*getPowerDeriv(T270,T130,1);
T2124 = (-(getPowerDeriv(T248,1+params(18),1)*T242*exp(y(19))*exp(y(88))*getPowerDeriv(exp(y(19))*exp(y(88)),T238,1)));
T2214 = getPowerDeriv(T1087,1+params(9),1);
T2228 = getPowerDeriv(T1123,1+params(168),1);
T2276 = exp(y(184))*T595*getPowerDeriv(T595,T553,1);
T2297 = exp(y(184))*getPowerDeriv(T595,T553,1)*(-(exp(y(48))*exp(y(47))*params(177)))/(exp(y(48))*exp(y(48)));
T2313 = getPowerDeriv(T591,1+params(64),1);
T2342 = (-(getPowerDeriv(T569,1+params(65),1)*T561*T563*exp(y(51))*getPowerDeriv(T563*exp(y(51)),T557,1)));
T2355 = getPowerDeriv(T638,1+params(182),1);
T2402 = exp(y(182))*(-(exp(y(55))*exp(y(56))*params(183)))/(exp(y(55))*exp(y(55)))*getPowerDeriv(T693,T553,1);
T2440 = (-(getPowerDeriv(T671,1+params(73),1)*T665*exp(y(58))*exp(y(89))*getPowerDeriv(exp(y(58))*exp(y(89)),T661,1)));
T2529 = getPowerDeriv(T1355,1+params(64),1);
T2543 = getPowerDeriv(T1391,1+params(182),1);
T2603 = (-(T242*exp(y(88))*exp(y(125))*getPowerDeriv(exp(y(88))*exp(y(125)),T238,1)*getPowerDeriv(T1146,1+params(18),1)));
T2631 = (-(T665*exp(y(89))*exp(y(151))*getPowerDeriv(exp(y(89))*exp(y(151)),T661,1)*getPowerDeriv(T1414,1+params(73),1)));
T2660 = (-(getPowerDeriv(T264,1+params(10),1)*T258*T140*exp(y(103))*getPowerDeriv(T140*exp(y(103)),T134,1)));
T2675 = (-(T138*T140*exp(y(118))*getPowerDeriv(T140*exp(y(118)),T134,1)*getPowerDeriv(T1076,1+params(10),1)));
T2691 = (-(T258*T140*exp(y(175))*getPowerDeriv(T140*exp(y(175)),T134,1)*getPowerDeriv(T1158,1+params(10),1)));
T2716 = (-(getPowerDeriv(T687,1+params(65),1)*T681*T563*exp(y(102))*getPowerDeriv(T563*exp(y(102)),T557,1)));
T2731 = (-(T561*T563*exp(y(144))*getPowerDeriv(T563*exp(y(144)),T557,1)*getPowerDeriv(T1344,1+params(65),1)));
T2747 = (-(T681*T563*exp(y(174))*getPowerDeriv(T563*exp(y(174)),T557,1)*getPowerDeriv(T1426,1+params(65),1)));
T2775 = (-(exp(y(100))*exp(y(205))))/(exp(y(100))*exp(y(100)));
T2787 = (-(exp(y(101))*exp(y(200))))/(exp(y(101))*exp(y(101)));
T2818 = (params(134)*exp(y(104))*params(134)*exp(y(104))-params(134)*exp(y(104))*(1+params(134)*exp(y(104))))/(params(134)*exp(y(104))*params(134)*exp(y(104)));
T2825 = (params(134)*exp(y(104))*(-(params(134)*exp(y(104))))-params(134)*exp(y(104))*(-(1+params(134)*exp(y(104)))))/(params(134)*exp(y(104))*params(134)*exp(y(104)));
T2842 = params(134)*exp(y(104))/(params(134)*exp(y(104))*params(134)*exp(y(104)));
T2867 = (params(135)*exp(y(105))*params(135)*exp(y(105))-params(135)*exp(y(105))*(1+params(135)*exp(y(105))))/(params(135)*exp(y(105))*params(135)*exp(y(105)));
T2874 = (params(135)*exp(y(105))*(-(params(135)*exp(y(105))))-params(135)*exp(y(105))*(-(1+params(135)*exp(y(105)))))/(params(135)*exp(y(105))*params(135)*exp(y(105)));
T2891 = params(135)*exp(y(105))/(params(135)*exp(y(105))*params(135)*exp(y(105)));
T2916 = (params(136)*exp(y(108))*params(136)*exp(y(108))-params(136)*exp(y(108))*(1+params(136)*exp(y(108))))/(params(136)*exp(y(108))*params(136)*exp(y(108)));
T2941 = params(136)*exp(y(108))/(params(136)*exp(y(108))*params(136)*exp(y(108)));
T2959 = (params(137)*exp(y(109))*params(137)*exp(y(109))-params(137)*exp(y(109))*(1+params(137)*exp(y(109))))/(params(137)*exp(y(109))*params(137)*exp(y(109)));
T2984 = params(137)*exp(y(109))/(params(137)*exp(y(109))*params(137)*exp(y(109)));
T3042 = exp(y(181))*getPowerDeriv(T1091,T130,1)*(-(exp(y(115))*params(163)*exp(y(114))))/(exp(y(115))*exp(y(115)));
T3135 = exp(y(177))*(-(exp(y(122))*params(169)*exp(y(123))))/(exp(y(122))*exp(y(122)))*getPowerDeriv(T1164,T130,1);
T3254 = exp(y(180))*getPowerDeriv(T1359,T553,1)*(-(exp(y(141))*params(177)*exp(y(140))))/(exp(y(141))*exp(y(141)));
T3347 = exp(y(176))*(-(exp(y(148))*params(183)*exp(y(149))))/(exp(y(148))*exp(y(148)))*getPowerDeriv(T1432,T553,1);
T3497 = (-(exp(y(180))*exp(y(181))*exp(y(162))))/(exp(y(180))*exp(y(180)));
T3523 = (-(exp(y(184))*exp(y(185))*exp(y(82))))/(exp(y(184))*exp(y(184)));
T3554 = getPowerDeriv(T1885*T1891*T1895,1-params(153),1);
T3567 = getPowerDeriv(T1817*T1819*T1823*T1831*T1839,1-params(146),1);
T3626 = 1/y(202);
T3627 = getPowerDeriv(T1712,(-(1+params(137)*exp(y(109))))/(params(137)*exp(y(109))),1);
T3632 = getPowerDeriv(T1712,1-(1+params(137)*exp(y(109)))/(params(137)*exp(y(109))),1);
T3679 = getPowerDeriv(T1767,(-(1+params(136)*exp(y(108))))/(params(136)*exp(y(108))),1);
T3684 = getPowerDeriv(T1767,1-(1+params(136)*exp(y(108)))/(params(136)*exp(y(108))),1);
T3727 = 1/y(212);
T3729 = T3727*getPowerDeriv(T1582,T1584,1);
T3733 = getPowerDeriv(T1582,1-(1+params(135)*exp(y(105)))/(params(135)*exp(y(105))),1);
T3747 = getPowerDeriv(T1582,T1584,1)*(-y(211))/(y(212)*y(212));
T3791 = 1/y(218);
T3793 = T3791*getPowerDeriv(T1645,T1647,1);
T3797 = getPowerDeriv(T1645,1-(1+params(134)*exp(y(104)))/(params(134)*exp(y(104))),1);
T3811 = getPowerDeriv(T1645,T1647,1)*(-y(217))/(y(218)*y(218));
lhs =y(1);
rhs =1/exp(y(39))*T20+params(161)/(1-params(129))*(1-exp(y(19)))^(1-params(129))+y(1)*params(5);
residual(1)= lhs-rhs;
lhs =y(2);
rhs =1/exp(y(78))*T48+params(175)/(1-params(127))*(1-exp(y(58)))^(1-params(127))+y(2)*params(60);
residual(2)= lhs-rhs;
lhs =T19^(-1);
rhs =exp(y(4))*exp(y(185));
residual(3)= lhs-rhs;
lhs =exp(y(107));
rhs =params(161)*(1-exp(y(19)))^(-params(129))/exp(y(4));
residual(4)= lhs-rhs;
residual(5) = 1-exp(y(5))*exp(y(34));
lhs =exp(y(5));
rhs =T108+T117;
residual(6)= lhs-rhs;
lhs =exp(y(7));
rhs =exp(y(7))*(1-params(6))/params(3)+exp(y(34))*exp(y(6));
residual(7)= lhs-rhs;
lhs =exp(y(8));
rhs =T146^(1+params(10));
residual(8)= lhs-rhs;
lhs =exp(y(9));
rhs =T168^(1+params(9));
residual(9)= lhs-rhs;
lhs =T174*T177;
rhs =1;
residual(10)= lhs-rhs;
lhs =exp(y(86));
rhs =T174*T184;
residual(11)= lhs-rhs;
lhs =exp(y(30));
rhs =T194;
residual(12)= lhs-rhs;
lhs =exp(y(6));
rhs =T215^(1+params(168));
residual(13)= lhs-rhs;
lhs =exp(y(14))*T219^T199;
rhs =1;
residual(14)= lhs-rhs;
lhs =exp(y(96));
rhs =exp(y(14))*T226^T199;
residual(15)= lhs-rhs;
lhs =exp(y(16));
rhs =T248^(1+params(18));
residual(16)= lhs-rhs;
lhs =exp(y(17));
rhs =T264^(1+params(10));
residual(17)= lhs-rhs;
lhs =exp(y(18));
rhs =T272*T276;
residual(18)= lhs-rhs;
lhs =exp(y(101))/exp(y(88));
rhs =T272*T285;
residual(19)= lhs-rhs;
lhs =exp(y(30));
rhs =T293;
residual(20)= lhs-rhs;
lhs =T296;
rhs =exp(y(10))+exp(y(13))+exp(y(25))+exp(y(97));
residual(21)= lhs-rhs;
lhs =exp(y(20));
rhs =exp(y(12))+exp(y(103));
residual(22)= lhs-rhs;
lhs =1/(1+y(21));
rhs =T313;
residual(23)= lhs-rhs;
lhs =exp(y(22));
rhs =exp(y(11))*exp(y(86))+exp(y(15))*exp(y(96));
residual(24)= lhs-rhs;
lhs =y(23);
rhs =(exp(y(97))-exp(y(22))+exp(y(84))*(params(29)*params(188)*exp(y(35))-exp(y(29))))/T296;
residual(25)= lhs-rhs;
lhs =y(24);
rhs =(exp(y(97))-exp(y(22)))/T296;
residual(26)= lhs-rhs;
lhs =exp(y(25));
rhs =T296*params(24)*exp(y(26));
residual(27)= lhs-rhs;
lhs =exp(y(20));
rhs =exp(y(27))^params(35)*T356;
residual(28)= lhs-rhs;
lhs =exp(y(28));
rhs =exp(y(28))*(1-params(36))/params(13)+exp(y(31));
residual(29)= lhs-rhs;
lhs =exp(y(29));
rhs =exp(y(27))+exp(y(31));
residual(30)= lhs-rhs;
lhs =exp(y(84));
rhs =exp(y(20))*exp(y(30))*params(35)/exp(y(27));
residual(31)= lhs-rhs;
lhs =exp(y(84));
rhs =T102*params(39)*(T378+exp(y(84))*(1-params(36)));
residual(32)= lhs-rhs;
lhs =y(26);
rhs =y(26)*params(31)+params(32)*x(1);
residual(33)= lhs-rhs;
lhs =y(32);
rhs =y(32)*(1+params(40)-params(41))-params(40)*y(33)+params(42)*x(2);
residual(34)= lhs-rhs;
lhs =exp(y(33));
rhs =exp(y(32));
residual(35)= lhs-rhs;
lhs =y(34);
rhs =y(34)*params(43)+params(44)*x(3);
residual(36)= lhs-rhs;
lhs =y(35);
rhs =y(35)*(1+params(45)-params(46))-params(45)*y(36)+params(47)*x(4);
residual(37)= lhs-rhs;
lhs =exp(y(36));
rhs =exp(y(35));
residual(38)= lhs-rhs;
lhs =y(37);
rhs =y(37)*(1+params(48)-params(49))-params(48)*y(38)+params(50)*x(5);
residual(39)= lhs-rhs;
lhs =exp(y(38));
rhs =exp(y(37));
residual(40)= lhs-rhs;
lhs =y(39);
rhs =y(39)*params(51)+params(52)*0.01*x(6);
residual(41)= lhs-rhs;
lhs =y(40);
rhs =y(40)*(1+params(53)-params(54))-params(53)*y(41)+params(55)*x(7);
residual(42)= lhs-rhs;
lhs =exp(y(41));
rhs =exp(y(40));
residual(43)= lhs-rhs;
lhs =exp(y(42));
rhs =exp(y(40));
residual(44)= lhs-rhs;
lhs =y(105);
rhs =y(105)*params(124)+params(125)*x(18);
residual(45)= lhs-rhs;
lhs =y(109);
rhs =y(109)*params(132)+params(133)*x(20);
residual(46)= lhs-rhs;
lhs =T47^(-1);
rhs =exp(y(43))*exp(y(184));
residual(47)= lhs-rhs;
lhs =exp(y(106));
rhs =params(175)*(1-exp(y(58)))^(-params(127))/exp(y(43));
residual(48)= lhs-rhs;
residual(49) = 1-exp(y(44))*exp(y(73));
lhs =exp(y(44));
rhs =T531+T540;
residual(50)= lhs-rhs;
lhs =exp(y(46));
rhs =exp(y(46))*(1-params(61))/params(58)+exp(y(73))*exp(y(45));
residual(51)= lhs-rhs;
lhs =exp(y(47));
rhs =T569^(1+params(65));
residual(52)= lhs-rhs;
lhs =exp(y(48));
rhs =T591^(1+params(64));
residual(53)= lhs-rhs;
lhs =T597*T600;
rhs =1;
residual(54)= lhs-rhs;
lhs =exp(y(87));
rhs =T597*T607;
residual(55)= lhs-rhs;
lhs =exp(y(69));
rhs =T617;
residual(56)= lhs-rhs;
lhs =exp(y(45));
rhs =T638^(1+params(182));
residual(57)= lhs-rhs;
lhs =exp(y(53))*T642^T622;
rhs =1;
residual(58)= lhs-rhs;
lhs =exp(y(98));
rhs =exp(y(53))*T649^T622;
residual(59)= lhs-rhs;
lhs =exp(y(55));
rhs =T671^(1+params(73));
residual(60)= lhs-rhs;
lhs =exp(y(56));
rhs =T687^(1+params(65));
residual(61)= lhs-rhs;
lhs =exp(y(57));
rhs =T695*T699;
residual(62)= lhs-rhs;
lhs =exp(y(100))/exp(y(89));
rhs =T695*T708;
residual(63)= lhs-rhs;
lhs =exp(y(69));
rhs =T716;
residual(64)= lhs-rhs;
lhs =exp(y(221));
rhs =exp(y(49))+exp(y(52))+exp(y(64))+exp(y(99));
residual(65)= lhs-rhs;
lhs =exp(y(59));
rhs =exp(y(51))+exp(y(102));
residual(66)= lhs-rhs;
lhs =1/(1+y(60));
rhs =T736;
residual(67)= lhs-rhs;
lhs =exp(y(61));
rhs =exp(y(50))*exp(y(87))+exp(y(54))*exp(y(98));
residual(68)= lhs-rhs;
lhs =y(62);
rhs =(exp(y(99))-exp(y(61))+exp(y(83))*(params(84)*params(189)*exp(y(74))-exp(y(68))))/exp(y(221));
residual(69)= lhs-rhs;
lhs =y(63);
rhs =(exp(y(99))-exp(y(61)))/exp(y(221));
residual(70)= lhs-rhs;
lhs =exp(y(64));
rhs =exp(y(221))*params(79)*exp(y(65));
residual(71)= lhs-rhs;
lhs =exp(y(59));
rhs =exp(y(66))^params(90)*T779;
residual(72)= lhs-rhs;
lhs =exp(y(67));
rhs =exp(y(67))*(1-params(91))/params(68)+exp(y(70));
residual(73)= lhs-rhs;
lhs =exp(y(68));
rhs =exp(y(66))+exp(y(70));
residual(74)= lhs-rhs;
lhs =exp(y(83));
rhs =exp(y(59))*exp(y(69))*params(90)/exp(y(66));
residual(75)= lhs-rhs;
lhs =exp(y(83));
rhs =T525*params(94)*(T801+exp(y(83))*(1-params(91)));
residual(76)= lhs-rhs;
lhs =y(65);
rhs =y(65)*params(86)+params(87)*x(8);
residual(77)= lhs-rhs;
lhs =y(71);
rhs =y(71)*(1+params(95)-params(96))-params(95)*y(72)+params(97)*x(9);
residual(78)= lhs-rhs;
lhs =exp(y(72));
rhs =exp(y(71));
residual(79)= lhs-rhs;
lhs =y(73);
rhs =y(73)*params(98)+params(99)*x(10);
residual(80)= lhs-rhs;
lhs =y(74);
rhs =y(74)*(1+params(100)-params(101))-params(100)*y(75)+params(102)*x(11);
residual(81)= lhs-rhs;
lhs =exp(y(75));
rhs =exp(y(74));
residual(82)= lhs-rhs;
lhs =y(76);
rhs =y(76)*(1+params(103)-params(104))-params(103)*y(77)+params(105)*x(12);
residual(83)= lhs-rhs;
lhs =exp(y(77));
rhs =exp(y(76));
residual(84)= lhs-rhs;
lhs =y(78);
rhs =y(78)*params(106)+0.01*params(107)*x(13);
residual(85)= lhs-rhs;
lhs =y(79);
rhs =y(79)*(1+params(108)-params(109))-params(108)*y(80)+params(110)*x(14);
residual(86)= lhs-rhs;
lhs =exp(y(80));
rhs =exp(y(79));
residual(87)= lhs-rhs;
lhs =exp(y(81));
rhs =exp(y(79));
residual(88)= lhs-rhs;
lhs =y(104);
rhs =y(104)*params(122)+params(123)*x(17);
residual(89)= lhs-rhs;
lhs =y(108);
rhs =y(108)*params(130)+params(131)*x(19);
residual(90)= lhs-rhs;
lhs =1;
rhs =exp(y(185))*exp(y(4))*exp((-params(111))*y(85))*exp(y(82))/exp(y(82))/exp(y(4))/exp(y(185));
residual(91)= lhs-rhs;
lhs =params(84)*params(189)*exp(y(74))+params(29)*params(188)*exp(y(35))*params(171);
rhs =exp(y(68))+exp(y(29))*params(171);
residual(92)= lhs-rhs;
lhs =exp(y(84));
rhs =T931;
residual(93)= lhs-rhs;
lhs =y(85)*T936;
rhs =y(23)+y(85);
residual(94)= lhs-rhs;
lhs =exp(y(86));
rhs =T930;
residual(95)= lhs-rhs;
lhs =exp(y(87));
rhs =T943;
residual(96)= lhs-rhs;
lhs =exp(y(96));
rhs =exp(y(86));
residual(97)= lhs-rhs;
lhs =exp(y(98));
rhs =exp(y(87));
residual(98)= lhs-rhs;
lhs =exp(y(97));
rhs =T947*(exp(y(50))+exp(y(54)));
residual(99)= lhs-rhs;
lhs =exp(y(99));
rhs =params(171)*(exp(y(11))+exp(y(15)));
residual(100)= lhs-rhs;
lhs =exp(y(88));
rhs =exp(y(32))*exp(y(90));
residual(101)= lhs-rhs;
lhs =exp(y(89));
rhs =exp(y(71))*exp(y(90));
residual(102)= lhs-rhs;
lhs =y(90);
rhs =y(90)*(1+params(114)-params(115))-params(114)*y(91)+params(116)*x(15);
residual(103)= lhs-rhs;
lhs =exp(y(91));
rhs =exp(y(90));
residual(104)= lhs-rhs;
lhs =T140;
rhs =exp(y(37))*exp(y(94));
residual(105)= lhs-rhs;
lhs =T563;
rhs =exp(y(76))*exp(y(94));
residual(106)= lhs-rhs;
lhs =y(94);
rhs =y(94)*(1+params(117)-params(118))-params(117)*y(95)+params(119)*x(16);
residual(107)= lhs-rhs;
lhs =exp(y(95));
rhs =exp(y(94));
residual(108)= lhs-rhs;
lhs =T1000^(-1);
rhs =exp(y(110))*exp(y(181));
residual(109)= lhs-rhs;
lhs =exp(y(179));
rhs =params(161)*(1-exp(y(125)))^(-params(129))/exp(y(110));
residual(110)= lhs-rhs;
lhs =exp(y(179))/exp(y(173));
rhs =(1+params(173))/(1+params(137)*exp(y(109)));
residual(111)= lhs-rhs;
residual(112) = 1-exp(y(34))*exp(y(111));
lhs =exp(y(111));
rhs =T1053+T1058;
residual(113)= lhs-rhs;
lhs =exp(y(113));
rhs =(1-params(6))/params(3)*exp(y(113))+exp(y(34))*exp(y(112));
residual(114)= lhs-rhs;
lhs =exp(y(114));
rhs =T1076^(1+params(10));
residual(115)= lhs-rhs;
lhs =exp(y(115));
rhs =T1087^(1+params(9));
residual(116)= lhs-rhs;
lhs =T1093*T1096;
rhs =1;
residual(117)= lhs-rhs;
lhs =exp(y(166));
rhs =T1093*T1102^T152;
residual(118)= lhs-rhs;
lhs =exp(y(134));
rhs =T1113;
residual(119)= lhs-rhs;
lhs =exp(y(112));
rhs =T1123^(1+params(168));
residual(120)= lhs-rhs;
lhs =exp(y(120))*T1127^T199;
rhs =1;
residual(121)= lhs-rhs;
lhs =exp(y(168));
rhs =exp(y(120))*T1134^T199;
residual(122)= lhs-rhs;
lhs =exp(y(122));
rhs =T1146^(1+params(18));
residual(123)= lhs-rhs;
lhs =exp(y(123));
rhs =T1158^(1+params(10));
residual(124)= lhs-rhs;
lhs =exp(y(124));
rhs =T1166*T1170;
residual(125)= lhs-rhs;
lhs =exp(y(173))/exp(y(88));
rhs =T1166*T1176^T235;
residual(126)= lhs-rhs;
lhs =exp(y(134));
rhs =T1185;
residual(127)= lhs-rhs;
lhs =exp(y(177));
rhs =(1+params(174))/(1+params(135)*exp(y(105)));
residual(128)= lhs-rhs;
lhs =exp(y(123));
rhs =exp(y(222));
residual(129)= lhs-rhs;
lhs =exp(y(222));
rhs =exp(y(116))+exp(y(119))+exp(y(130))+exp(y(169));
residual(130)= lhs-rhs;
lhs =exp(y(126));
rhs =exp(y(118))+exp(y(175));
residual(131)= lhs-rhs;
lhs =1/(1+y(127));
rhs =T102*exp(y(110))/exp(y(110));
residual(132)= lhs-rhs;
lhs =exp(y(128));
rhs =exp(y(117))*exp(y(166))+exp(y(121))*exp(y(168));
residual(133)= lhs-rhs;
lhs =y(129);
rhs =(exp(y(169))-exp(y(128))+exp(y(164))*(params(29)*params(188)*exp(y(35))-exp(y(133))))/exp(y(222));
residual(134)= lhs-rhs;
lhs =exp(y(130));
rhs =exp(y(26))*params(24)*exp(y(222));
residual(135)= lhs-rhs;
lhs =exp(y(126));
rhs =exp(y(131))^params(35)*T1242;
residual(136)= lhs-rhs;
lhs =exp(y(132));
rhs =(1-params(36))/params(13)*exp(y(132))+exp(y(135));
residual(137)= lhs-rhs;
lhs =exp(y(133));
rhs =exp(y(131))+exp(y(135));
residual(138)= lhs-rhs;
lhs =exp(y(164));
rhs =exp(y(126))*params(35)*exp(y(134))/exp(y(131));
residual(139)= lhs-rhs;
lhs =exp(y(164));
rhs =T102*params(39)*(T1259+(1-params(36))*exp(y(164)));
residual(140)= lhs-rhs;
lhs =T1268^(-1);
rhs =exp(y(136))*exp(y(180));
residual(141)= lhs-rhs;
lhs =exp(y(178));
rhs =params(175)*(1-exp(y(151)))^(-params(127))/exp(y(136));
residual(142)= lhs-rhs;
lhs =exp(y(178))/exp(y(172));
rhs =(1+params(186))/(1+params(136)*exp(y(108)));
residual(143)= lhs-rhs;
residual(144) = 1-exp(y(73))*exp(y(137));
lhs =exp(y(137));
rhs =T1321+T1326;
residual(145)= lhs-rhs;
lhs =exp(y(139));
rhs =(1-params(61))/params(58)*exp(y(139))+exp(y(73))*exp(y(138));
residual(146)= lhs-rhs;
lhs =exp(y(140));
rhs =T1344^(1+params(65));
residual(147)= lhs-rhs;
lhs =exp(y(141));
rhs =T1355^(1+params(64));
residual(148)= lhs-rhs;
lhs =T1361*T1364;
rhs =1;
residual(149)= lhs-rhs;
lhs =exp(y(167));
rhs =T1361*T1370^T575;
residual(150)= lhs-rhs;
lhs =exp(y(160));
rhs =T1381;
residual(151)= lhs-rhs;
lhs =exp(y(138));
rhs =T1391^(1+params(182));
residual(152)= lhs-rhs;
lhs =exp(y(146))*T1395^T622;
rhs =1;
residual(153)= lhs-rhs;
lhs =exp(y(170));
rhs =exp(y(146))*T1402^T622;
residual(154)= lhs-rhs;
lhs =exp(y(148));
rhs =T1414^(1+params(73));
residual(155)= lhs-rhs;
lhs =exp(y(149));
rhs =T1426^(1+params(65));
residual(156)= lhs-rhs;
lhs =exp(y(150));
rhs =T1434*T1438;
residual(157)= lhs-rhs;
lhs =exp(y(172))/exp(y(89));
rhs =T1434*T1444^T658;
residual(158)= lhs-rhs;
lhs =exp(y(160));
rhs =T1453;
residual(159)= lhs-rhs;
lhs =exp(y(176));
rhs =(1+params(187))/(1+params(134)*exp(y(104)));
residual(160)= lhs-rhs;
lhs =exp(y(149));
rhs =exp(y(223));
residual(161)= lhs-rhs;
lhs =exp(y(223));
rhs =exp(y(142))+exp(y(145))+exp(y(156))+exp(y(171));
residual(162)= lhs-rhs;
lhs =exp(y(152));
rhs =exp(y(144))+exp(y(174));
residual(163)= lhs-rhs;
lhs =1/(1+y(153));
rhs =T1482;
residual(164)= lhs-rhs;
lhs =exp(y(154));
rhs =exp(y(143))*exp(y(167))+exp(y(147))*exp(y(170));
residual(165)= lhs-rhs;
lhs =y(155);
rhs =(exp(y(171))-exp(y(154))+exp(y(163))*(params(84)*params(189)*exp(y(74))-exp(y(159))))/exp(y(223));
residual(166)= lhs-rhs;
lhs =exp(y(156));
rhs =exp(y(65))*params(79)*exp(y(223));
residual(167)= lhs-rhs;
lhs =exp(y(152));
rhs =exp(y(157))^params(90)*T1510;
residual(168)= lhs-rhs;
lhs =exp(y(158));
rhs =(1-params(91))/params(68)*exp(y(158))+exp(y(161));
residual(169)= lhs-rhs;
lhs =exp(y(159));
rhs =exp(y(157))+exp(y(161));
residual(170)= lhs-rhs;
lhs =exp(y(163));
rhs =exp(y(152))*params(90)*exp(y(160))/exp(y(157));
residual(171)= lhs-rhs;
lhs =exp(y(163));
rhs =T525*params(94)*(T1527+(1-params(91))*exp(y(163)));
residual(172)= lhs-rhs;
lhs =1;
rhs =exp(y(181))*exp(y(110))*exp((-params(111))*y(165))*exp(y(162))/exp(y(162))/exp(y(110))/exp(y(181));
residual(173)= lhs-rhs;
lhs =params(84)*params(189)*exp(y(74))+params(29)*params(188)*exp(y(35))*params(171);
rhs =exp(y(159))+params(171)*exp(y(133));
residual(174)= lhs-rhs;
lhs =exp(y(164));
rhs =T1549;
residual(175)= lhs-rhs;
lhs =T1555;
rhs =y(129)+y(165);
residual(176)= lhs-rhs;
lhs =exp(y(166));
rhs =T1548;
residual(177)= lhs-rhs;
lhs =exp(y(167));
rhs =T1561;
residual(178)= lhs-rhs;
lhs =exp(y(168));
rhs =exp(y(166));
residual(179)= lhs-rhs;
lhs =exp(y(170));
rhs =exp(y(167));
residual(180)= lhs-rhs;
lhs =exp(y(169));
rhs =T947*(exp(y(143))+exp(y(147)));
residual(181)= lhs-rhs;
lhs =exp(y(171));
rhs =params(171)*(exp(y(117))+exp(y(121)));
residual(182)= lhs-rhs;
lhs =exp(y(208));
rhs =T1575+exp(y(208))*T1579*T1585;
residual(183)= lhs-rhs;
lhs =exp(y(209));
rhs =T296*(1+params(174))/(params(135)*exp(y(105)))+exp(y(209))*T1579*T1595;
residual(184)= lhs-rhs;
lhs =exp(y(210));
rhs =exp(y(208))/exp(y(209));
residual(185)= lhs-rhs;
lhs =(1-params(141))*T1606+params(141)*T1608;
rhs =1;
residual(186)= lhs-rhs;
lhs =y(211);
rhs =y(212)^params(140)*params(172)^(1-params(140));
residual(187)= lhs-rhs;
lhs =exp(y(17));
rhs =T296*exp(y(213));
residual(188)= lhs-rhs;
lhs =exp(y(213));
rhs =(1-params(141))*exp(y(210))^T1584+exp(y(213))*params(141)*T1585;
residual(189)= lhs-rhs;
lhs =log(y(212));
rhs =log(params(172))+y(187);
residual(190)= lhs-rhs;
lhs =exp(y(214));
rhs =T1638+exp(y(214))*T1642*T1648;
residual(191)= lhs-rhs;
lhs =exp(y(215));
rhs =exp(y(221))*(1+params(187))/(params(134)*exp(y(104)))+exp(y(215))*T1642*T1658;
residual(192)= lhs-rhs;
lhs =exp(y(216));
rhs =exp(y(214))/exp(y(215));
residual(193)= lhs-rhs;
lhs =(1-params(139))*T1669+params(139)*T1671;
rhs =1;
residual(194)= lhs-rhs;
lhs =y(217);
rhs =y(218)^params(138)*params(185)^(1-params(138));
residual(195)= lhs-rhs;
lhs =exp(y(56));
rhs =exp(y(221))*exp(y(219));
residual(196)= lhs-rhs;
lhs =exp(y(219));
rhs =(1-params(139))*exp(y(216))^T1647+exp(y(219))*params(139)*T1648;
residual(197)= lhs-rhs;
lhs =log(y(218));
rhs =log(params(185))+y(186);
residual(198)= lhs-rhs;
lhs =exp(y(198));
rhs =T1702+exp(y(198))*T1710*T1715;
residual(199)= lhs-rhs;
lhs =exp(y(199));
rhs =exp(y(19))*(1+params(173))/(params(137)*exp(y(109)))+exp(y(199))*T1710*T1725;
residual(200)= lhs-rhs;
lhs =T1732;
rhs =exp(y(198))/exp(y(199));
residual(201)= lhs-rhs;
lhs =(1-params(145))*T1732^T1736+params(145)*T1712^T1736;
rhs =1;
residual(202)= lhs-rhs;
lhs =y(201);
rhs =y(202)^params(144)*(params(3)*params(172))^(1-params(144));
residual(203)= lhs-rhs;
lhs =y(202);
rhs =params(3)*y(212);
residual(204)= lhs-rhs;
lhs =exp(y(203));
rhs =T1757+exp(y(203))*T1765*T1770;
residual(205)= lhs-rhs;
lhs =exp(y(204));
rhs =exp(y(58))*(1+params(186))/(params(136)*exp(y(108)))+exp(y(204))*T1765*T1780;
residual(206)= lhs-rhs;
lhs =T1787;
rhs =exp(y(203))/exp(y(204));
residual(207)= lhs-rhs;
lhs =(1-params(143))*T1787^T1791+params(143)*T1767^T1791;
rhs =1;
residual(208)= lhs-rhs;
lhs =y(206);
rhs =y(207)^params(142)*(params(58)*params(185))^(1-params(142));
residual(209)= lhs-rhs;
lhs =y(207);
rhs =params(58)*y(218);
residual(210)= lhs-rhs;
lhs =(1+y(194))/(1+params(190));
rhs =T1813*(T1817*T1819*T1823*T1831*T1839)^(1-params(146))*T1851;
residual(211)= lhs-rhs;
lhs =y(3);
rhs =T1821;
residual(212)= lhs-rhs;
lhs =1/(1+y(194));
rhs =T313/(1+y(187));
residual(213)= lhs-rhs;
lhs =exp(y(193));
rhs =T174;
residual(214)= lhs-rhs;
lhs =y(189);
rhs =log(y(212));
residual(215)= lhs-rhs;
lhs =y(190);
rhs =log(y(212));
residual(216)= lhs-rhs;
lhs =y(191);
rhs =log(y(212))+log(params(39));
residual(217)= lhs-rhs;
lhs =y(196);
rhs =y(196)*params(157)+params(158)*x(21);
residual(218)= lhs-rhs;
lhs =(1+y(195))/(1+params(191));
rhs =T1881*T1898;
residual(219)= lhs-rhs;
lhs =1/(1+y(195));
rhs =T736/(1+y(186));
residual(220)= lhs-rhs;
lhs =exp(y(192));
rhs =T597;
residual(221)= lhs-rhs;
lhs =y(188);
rhs =log(y(218));
residual(222)= lhs-rhs;
lhs =y(197);
rhs =y(197)*params(159)+params(160)*x(22);
residual(223)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(223, 223);

  %
  % Jacobian matrix
  %

  g1(1,1)=1-params(5);
  g1(1,8)=(-(1/exp(y(39))));
  g1(1,19)=(-(params(161)/(1-params(129))*(-exp(y(19)))*getPowerDeriv(1-exp(y(19)),1-params(129),1)));
  g1(1,39)=(-(T20*(-exp(y(39)))/(exp(y(39))*exp(y(39)))+1/exp(y(39))*exp(y(39))*exp(y(8))/T19));
  g1(2,2)=1-params(60);
  g1(2,47)=(-(1/exp(y(78))));
  g1(2,58)=(-(params(175)/(1-params(127))*(-exp(y(58)))*getPowerDeriv(1-exp(y(58)),1-params(127),1)));
  g1(2,78)=(-(T48*(-exp(y(78)))/(exp(y(78))*exp(y(78)))+1/exp(y(78))*exp(y(78))*exp(y(47))/T47));
  g1(3,4)=(-(exp(y(4))*exp(y(185))));
  g1(3,8)=T19*getPowerDeriv(T19,(-1),1);
  g1(3,39)=exp(y(39))*exp(y(8))*getPowerDeriv(T19,(-1),1);
  g1(3,185)=(-(exp(y(4))*exp(y(185))));
  g1(4,4)=(-((-(exp(y(4))*params(161)*(1-exp(y(19)))^(-params(129))))/(exp(y(4))*exp(y(4)))));
  g1(4,19)=(-(params(161)*(-exp(y(19)))*getPowerDeriv(1-exp(y(19)),(-params(129)),1)/exp(y(4))));
  g1(4,107)=exp(y(107));
  g1(5,5)=(-(exp(y(5))*exp(y(34))));
  g1(5,34)=(-(exp(y(5))*exp(y(34))));
  g1(6,5)=exp(y(5))-T117;
  g1(6,14)=(-(exp(y(18))*exp(y(4))*(-(exp(y(14))*T102))/(exp(y(14))*exp(y(14)))/exp(y(4))));
  g1(6,18)=(-T108);
  g1(7,6)=(-(exp(y(34))*exp(y(6))));
  g1(7,7)=exp(y(7))-exp(y(7))*(1-params(6))/params(3);
  g1(7,34)=(-(exp(y(34))*exp(y(6))));
  g1(8,8)=exp(y(8));
  g1(8,9)=(-(T131*exp(y(9))*getPowerDeriv(exp(y(9)),T134,1)*getPowerDeriv(T146,1+params(10),1)));
  g1(8,12)=T2026;
  g1(8,92)=T2026;
  g1(9,9)=exp(y(9));
  g1(9,10)=(-(T153*exp(y(10))*getPowerDeriv(exp(y(10)),T156,1)*T1997));
  g1(9,11)=(-(T1997*T163*exp(y(11))*getPowerDeriv(exp(y(11)),T156,1)));
  g1(9,40)=(-(T1997*exp(y(11))^T156*params(165)*exp(y(40))*getPowerDeriv(params(165)*exp(y(40)),T152,1)));
  g1(10,8)=T177*T1960;
  g1(10,9)=T177*T1981+T174*T176*getPowerDeriv(T176,T152,1);
  g1(10,10)=T174*getPowerDeriv(T176,T152,1)*(-(exp(y(10))*exp(y(9))*params(164)))/(exp(y(10))*exp(y(10)));
  g1(10,185)=T174*T177;
  g1(11,8)=(-(T184*T1960));
  g1(11,9)=(-(T184*T1981+T174*T183*getPowerDeriv(T183,T152,1)));
  g1(11,11)=(-(T174*getPowerDeriv(T183,T152,1)*(-(exp(y(11))*exp(y(9))*params(165)*exp(y(40))))/(exp(y(11))*exp(y(11)))));
  g1(11,40)=(-(T174*T183*getPowerDeriv(T183,T152,1)));
  g1(11,86)=exp(y(86));
  g1(11,185)=(-(T174*T184));
  g1(12,8)=(-(T140*exp(y(185))*T191*getPowerDeriv(T191,T130,1)));
  g1(12,12)=(-(T140*exp(y(185))*getPowerDeriv(T191,T130,1)*(-(exp(y(12))*exp(y(8))*params(162)/T140))/(exp(y(12))*exp(y(12)))));
  g1(12,30)=exp(y(30));
  g1(12,92)=(-(T194+T140*exp(y(185))*getPowerDeriv(T191,T130,1)*(-(T140*exp(y(8))*params(162)))/(T140*T140)/exp(y(12))));
  g1(12,185)=(-T194);
  g1(13,6)=exp(y(6));
  g1(13,13)=(-(T200*exp(y(13))*getPowerDeriv(exp(y(13)),T203,1)*T2039));
  g1(13,15)=(-(T2039*T210*exp(y(15))*getPowerDeriv(exp(y(15)),T203,1)));
  g1(13,42)=(-(T2039*exp(y(15))^T203*params(167)*exp(y(42))*getPowerDeriv(params(167)*exp(y(42)),T199,1)));
  g1(14,6)=exp(y(14))*T219*getPowerDeriv(T219,T199,1);
  g1(14,13)=exp(y(14))*getPowerDeriv(T219,T199,1)*(-(exp(y(13))*exp(y(6))*params(166)))/(exp(y(13))*exp(y(13)));
  g1(14,14)=exp(y(14))*T219^T199;
  g1(15,6)=(-(exp(y(14))*T226*getPowerDeriv(T226,T199,1)));
  g1(15,14)=(-(exp(y(14))*T226^T199));
  g1(15,15)=(-(exp(y(14))*getPowerDeriv(T226,T199,1)*(-(exp(y(15))*exp(y(6))*params(167)*exp(y(42))))/(exp(y(15))*exp(y(15)))));
  g1(15,42)=(-(exp(y(14))*T226*getPowerDeriv(T226,T199,1)));
  g1(15,96)=exp(y(96));
  g1(16,7)=(-(T236*exp(y(7))/params(3)*getPowerDeriv(exp(y(7))/params(3),T238,1)*getPowerDeriv(T248,1+params(18),1)));
  g1(16,16)=exp(y(16));
  g1(16,19)=T2124;
  g1(16,88)=T2124;
  g1(17,16)=(-(T254*exp(y(16))*getPowerDeriv(exp(y(16)),T134,1)*getPowerDeriv(T264,1+params(10),1)));
  g1(17,17)=exp(y(17));
  g1(17,92)=T2660;
  g1(17,103)=T2660;
  g1(18,7)=(-(T272*(-(exp(y(7))*params(3)*exp(y(16))*params(15)))/(exp(y(7))*exp(y(7)))*getPowerDeriv(T275,T235,1)));
  g1(18,16)=(-(T276*T2086+T272*T275*getPowerDeriv(T275,T235,1)));
  g1(18,17)=(-(T276*exp(y(183))*T270*getPowerDeriv(T270,T130,1)));
  g1(18,18)=exp(y(18));
  g1(18,183)=(-(T272*T276));
  g1(19,16)=(-(T285*T2086+T272*T284*getPowerDeriv(T284,T235,1)));
  g1(19,17)=(-(T285*exp(y(183))*T270*getPowerDeriv(T270,T130,1)));
  g1(19,19)=(-(T272*getPowerDeriv(T284,T235,1)*(-(exp(y(19))*exp(y(16))*params(19)/exp(y(88))))/(exp(y(19))*exp(y(19)))));
  g1(19,88)=(-(exp(y(88))*exp(y(101))))/(exp(y(88))*exp(y(88)))-T272*getPowerDeriv(T284,T235,1)*(-(exp(y(88))*exp(y(16))*params(19)))/(exp(y(88))*exp(y(88)))/exp(y(19));
  g1(19,101)=exp(y(101))/exp(y(88));
  g1(19,183)=(-(T272*T285));
  g1(20,17)=(-(T140*exp(y(183))*T290*getPowerDeriv(T290,T130,1)));
  g1(20,30)=exp(y(30));
  g1(20,92)=(-(T293+T140*exp(y(183))*getPowerDeriv(T290,T130,1)*(-(T140*exp(y(17))*params(170)))/(T140*T140)/exp(y(103))));
  g1(20,103)=(-(T140*exp(y(183))*getPowerDeriv(T290,T130,1)*(-(exp(y(103))*exp(y(17))*params(170)/T140))/(exp(y(103))*exp(y(103)))));
  g1(20,183)=(-T293);
  g1(21,10)=(-exp(y(10)));
  g1(21,13)=(-exp(y(13)));
  g1(21,25)=(-exp(y(25)));
  g1(21,97)=(-exp(y(97)));
  g1(21,220)=T296;
  g1(22,12)=(-exp(y(12)));
  g1(22,20)=exp(y(20));
  g1(22,103)=(-exp(y(103)));
  g1(23,21)=(-1)/((1+y(21))*(1+y(21)));
  g1(24,11)=(-(exp(y(11))*exp(y(86))));
  g1(24,15)=(-(exp(y(15))*exp(y(96))));
  g1(24,22)=exp(y(22));
  g1(24,86)=(-(exp(y(11))*exp(y(86))));
  g1(24,96)=(-(exp(y(15))*exp(y(96))));
  g1(25,22)=(-((-exp(y(22)))/T296));
  g1(25,23)=1;
  g1(25,29)=(-(exp(y(84))*(-exp(y(29)))/T296));
  g1(25,35)=(-(exp(y(84))*params(29)*params(188)*exp(y(35))/T296));
  g1(25,84)=(-(exp(y(84))*(params(29)*params(188)*exp(y(35))-exp(y(29)))/T296));
  g1(25,97)=(-(exp(y(97))/T296));
  g1(25,220)=(-((-(T296*(exp(y(97))-exp(y(22))+exp(y(84))*(params(29)*params(188)*exp(y(35))-exp(y(29))))))/(T296*T296)));
  g1(26,22)=(-((-exp(y(22)))/T296));
  g1(26,24)=1;
  g1(26,97)=(-(exp(y(97))/T296));
  g1(26,220)=(-((-(T296*(exp(y(97))-exp(y(22)))))/(T296*T296)));
  g1(27,25)=exp(y(25));
  g1(27,26)=(-(T296*params(24)*exp(y(26))));
  g1(27,220)=(-(T296*params(24)*exp(y(26))));
  g1(28,20)=exp(y(20));
  g1(28,27)=(-(T356*exp(y(27))*getPowerDeriv(exp(y(27)),params(35),1)));
  g1(28,28)=(-(exp(y(27))^params(35)*exp(y(28))/params(13)*getPowerDeriv(exp(y(28))/params(13),1-params(35),1)));
  g1(29,28)=exp(y(28))-exp(y(28))*(1-params(36))/params(13);
  g1(29,31)=(-exp(y(31)));
  g1(30,27)=(-exp(y(27)));
  g1(30,29)=exp(y(29));
  g1(30,31)=(-exp(y(31)));
  g1(31,20)=(-(exp(y(20))*exp(y(30))*params(35)/exp(y(27))));
  g1(31,27)=(-((-(exp(y(27))*exp(y(20))*exp(y(30))*params(35)))/(exp(y(27))*exp(y(27)))));
  g1(31,30)=(-(exp(y(20))*exp(y(30))*params(35)/exp(y(27))));
  g1(31,84)=exp(y(84));
  g1(32,20)=(-(T102*params(39)*T378));
  g1(32,28)=(-(T102*params(39)*(-(exp(y(28))*exp(y(20))*params(13)*exp(y(30))*(1-params(35))))/(exp(y(28))*exp(y(28)))));
  g1(32,30)=(-(T102*params(39)*T378));
  g1(32,84)=exp(y(84))-T102*params(39)*exp(y(84))*(1-params(36));
  g1(33,26)=1-params(31);
  g1(34,32)=1-(1+params(40)-params(41));
  g1(34,33)=params(40);
  g1(35,32)=(-exp(y(32)));
  g1(35,33)=exp(y(33));
  g1(36,34)=1-params(43);
  g1(37,35)=1-(1+params(45)-params(46));
  g1(37,36)=params(45);
  g1(38,35)=(-exp(y(35)));
  g1(38,36)=exp(y(36));
  g1(39,37)=1-(1+params(48)-params(49));
  g1(39,38)=params(48);
  g1(40,37)=(-exp(y(37)));
  g1(40,38)=exp(y(38));
  g1(41,39)=1-params(51);
  g1(42,40)=1-(1+params(53)-params(54));
  g1(42,41)=params(53);
  g1(43,40)=(-exp(y(40)));
  g1(43,41)=exp(y(41));
  g1(44,40)=(-exp(y(40)));
  g1(44,42)=exp(y(42));
  g1(45,105)=1-params(124);
  g1(46,109)=1-params(132);
  g1(47,43)=(-(exp(y(43))*exp(y(184))));
  g1(47,47)=T47*getPowerDeriv(T47,(-1),1);
  g1(47,78)=exp(y(78))*exp(y(47))*getPowerDeriv(T47,(-1),1);
  g1(47,184)=(-(exp(y(43))*exp(y(184))));
  g1(48,43)=(-((-(exp(y(43))*params(175)*(1-exp(y(58)))^(-params(127))))/(exp(y(43))*exp(y(43)))));
  g1(48,58)=(-(params(175)*(-exp(y(58)))*getPowerDeriv(1-exp(y(58)),(-params(127)),1)/exp(y(43))));
  g1(48,106)=exp(y(106));
  g1(49,44)=(-(exp(y(44))*exp(y(73))));
  g1(49,73)=(-(exp(y(44))*exp(y(73))));
  g1(50,44)=exp(y(44))-T540;
  g1(50,53)=(-(exp(y(57))*exp(y(43))*(-(exp(y(53))*T525))/(exp(y(53))*exp(y(53)))/exp(y(43))));
  g1(50,57)=(-T531);
  g1(51,45)=(-(exp(y(73))*exp(y(45))));
  g1(51,46)=exp(y(46))-exp(y(46))*(1-params(61))/params(58);
  g1(51,73)=(-(exp(y(73))*exp(y(45))));
  g1(52,47)=exp(y(47));
  g1(52,48)=(-(T554*exp(y(48))*getPowerDeriv(exp(y(48)),T557,1)*getPowerDeriv(T569,1+params(65),1)));
  g1(52,51)=T2342;
  g1(52,93)=T2342;
  g1(53,48)=exp(y(48));
  g1(53,49)=(-(T576*exp(y(49))*getPowerDeriv(exp(y(49)),T579,1)*T2313));
  g1(53,50)=(-(T2313*T586*exp(y(50))*getPowerDeriv(exp(y(50)),T579,1)));
  g1(53,79)=(-(T2313*exp(y(50))^T579*params(179)*exp(y(79))*getPowerDeriv(params(179)*exp(y(79)),T575,1)));
  g1(54,47)=T600*T2276;
  g1(54,48)=T600*T2297+T597*T599*getPowerDeriv(T599,T575,1);
  g1(54,49)=T597*getPowerDeriv(T599,T575,1)*(-(exp(y(49))*exp(y(48))*params(178)))/(exp(y(49))*exp(y(49)));
  g1(54,184)=T597*T600;
  g1(55,47)=(-(T607*T2276));
  g1(55,48)=(-(T607*T2297+T597*T606*getPowerDeriv(T606,T575,1)));
  g1(55,50)=(-(T597*getPowerDeriv(T606,T575,1)*(-(exp(y(50))*exp(y(48))*params(179)*exp(y(79))))/(exp(y(50))*exp(y(50)))));
  g1(55,79)=(-(T597*T606*getPowerDeriv(T606,T575,1)));
  g1(55,87)=exp(y(87));
  g1(55,184)=(-(T597*T607));
  g1(56,47)=(-(T563*exp(y(184))*T614*getPowerDeriv(T614,T553,1)));
  g1(56,51)=(-(T563*exp(y(184))*getPowerDeriv(T614,T553,1)*(-(exp(y(51))*exp(y(47))*params(176)/T563))/(exp(y(51))*exp(y(51)))));
  g1(56,69)=exp(y(69));
  g1(56,93)=(-(T617+T563*exp(y(184))*getPowerDeriv(T614,T553,1)*(-(T563*exp(y(47))*params(176)))/(T563*T563)/exp(y(51))));
  g1(56,184)=(-T617);
  g1(57,45)=exp(y(45));
  g1(57,52)=(-(T623*exp(y(52))*getPowerDeriv(exp(y(52)),T626,1)*T2355));
  g1(57,54)=(-(T2355*T633*exp(y(54))*getPowerDeriv(exp(y(54)),T626,1)));
  g1(57,81)=(-(T2355*exp(y(54))^T626*params(181)*exp(y(81))*getPowerDeriv(params(181)*exp(y(81)),T622,1)));
  g1(58,45)=exp(y(53))*T642*getPowerDeriv(T642,T622,1);
  g1(58,52)=exp(y(53))*getPowerDeriv(T642,T622,1)*(-(exp(y(52))*exp(y(45))*params(180)))/(exp(y(52))*exp(y(52)));
  g1(58,53)=exp(y(53))*T642^T622;
  g1(59,45)=(-(exp(y(53))*T649*getPowerDeriv(T649,T622,1)));
  g1(59,53)=(-(exp(y(53))*T649^T622));
  g1(59,54)=(-(exp(y(53))*getPowerDeriv(T649,T622,1)*(-(exp(y(54))*exp(y(45))*params(181)*exp(y(81))))/(exp(y(54))*exp(y(54)))));
  g1(59,81)=(-(exp(y(53))*T649*getPowerDeriv(T649,T622,1)));
  g1(59,98)=exp(y(98));
  g1(60,46)=(-(T659*exp(y(46))/params(58)*getPowerDeriv(exp(y(46))/params(58),T661,1)*getPowerDeriv(T671,1+params(73),1)));
  g1(60,55)=exp(y(55));
  g1(60,58)=T2440;
  g1(60,89)=T2440;
  g1(61,55)=(-(T677*exp(y(55))*getPowerDeriv(exp(y(55)),T557,1)*getPowerDeriv(T687,1+params(65),1)));
  g1(61,56)=exp(y(56));
  g1(61,93)=T2716;
  g1(61,102)=T2716;
  g1(62,46)=(-(T695*(-(exp(y(46))*params(58)*exp(y(55))*params(70)))/(exp(y(46))*exp(y(46)))*getPowerDeriv(T698,T658,1)));
  g1(62,55)=(-(T699*T2402+T695*T698*getPowerDeriv(T698,T658,1)));
  g1(62,56)=(-(T699*exp(y(182))*T693*getPowerDeriv(T693,T553,1)));
  g1(62,57)=exp(y(57));
  g1(62,182)=(-(T695*T699));
  g1(63,55)=(-(T708*T2402+T695*T707*getPowerDeriv(T707,T658,1)));
  g1(63,56)=(-(T708*exp(y(182))*T693*getPowerDeriv(T693,T553,1)));
  g1(63,58)=(-(T695*getPowerDeriv(T707,T658,1)*(-(exp(y(58))*exp(y(55))*params(74)/exp(y(89))))/(exp(y(58))*exp(y(58)))));
  g1(63,89)=(-(exp(y(89))*exp(y(100))))/(exp(y(89))*exp(y(89)))-T695*getPowerDeriv(T707,T658,1)*(-(exp(y(89))*exp(y(55))*params(74)))/(exp(y(89))*exp(y(89)))/exp(y(58));
  g1(63,100)=exp(y(100))/exp(y(89));
  g1(63,182)=(-(T695*T708));
  g1(64,56)=(-(T563*exp(y(182))*T713*getPowerDeriv(T713,T553,1)));
  g1(64,69)=exp(y(69));
  g1(64,93)=(-(T716+T563*exp(y(182))*getPowerDeriv(T713,T553,1)*(-(T563*exp(y(56))*params(184)))/(T563*T563)/exp(y(102))));
  g1(64,102)=(-(T563*exp(y(182))*getPowerDeriv(T713,T553,1)*(-(exp(y(102))*exp(y(56))*params(184)/T563))/(exp(y(102))*exp(y(102)))));
  g1(64,182)=(-T716);
  g1(65,49)=(-exp(y(49)));
  g1(65,52)=(-exp(y(52)));
  g1(65,64)=(-exp(y(64)));
  g1(65,99)=(-exp(y(99)));
  g1(65,221)=exp(y(221));
  g1(66,51)=(-exp(y(51)));
  g1(66,59)=exp(y(59));
  g1(66,102)=(-exp(y(102)));
  g1(67,60)=(-1)/((1+y(60))*(1+y(60)));
  g1(68,50)=(-(exp(y(50))*exp(y(87))));
  g1(68,54)=(-(exp(y(54))*exp(y(98))));
  g1(68,61)=exp(y(61));
  g1(68,87)=(-(exp(y(50))*exp(y(87))));
  g1(68,98)=(-(exp(y(54))*exp(y(98))));
  g1(69,61)=(-((-exp(y(61)))/exp(y(221))));
  g1(69,62)=1;
  g1(69,68)=(-(exp(y(83))*(-exp(y(68)))/exp(y(221))));
  g1(69,74)=(-(exp(y(83))*params(84)*params(189)*exp(y(74))/exp(y(221))));
  g1(69,83)=(-(exp(y(83))*(params(84)*params(189)*exp(y(74))-exp(y(68)))/exp(y(221))));
  g1(69,99)=(-(exp(y(99))/exp(y(221))));
  g1(69,221)=(-((-(exp(y(221))*(exp(y(99))-exp(y(61))+exp(y(83))*(params(84)*params(189)*exp(y(74))-exp(y(68))))))/(exp(y(221))*exp(y(221)))));
  g1(70,61)=(-((-exp(y(61)))/exp(y(221))));
  g1(70,63)=1;
  g1(70,99)=(-(exp(y(99))/exp(y(221))));
  g1(70,221)=(-((-(exp(y(221))*(exp(y(99))-exp(y(61)))))/(exp(y(221))*exp(y(221)))));
  g1(71,64)=exp(y(64));
  g1(71,65)=(-(exp(y(221))*params(79)*exp(y(65))));
  g1(71,221)=(-(exp(y(221))*params(79)*exp(y(65))));
  g1(72,59)=exp(y(59));
  g1(72,66)=(-(T779*exp(y(66))*getPowerDeriv(exp(y(66)),params(90),1)));
  g1(72,67)=(-(exp(y(66))^params(90)*exp(y(67))/params(68)*getPowerDeriv(exp(y(67))/params(68),1-params(90),1)));
  g1(73,67)=exp(y(67))-exp(y(67))*(1-params(91))/params(68);
  g1(73,70)=(-exp(y(70)));
  g1(74,66)=(-exp(y(66)));
  g1(74,68)=exp(y(68));
  g1(74,70)=(-exp(y(70)));
  g1(75,59)=(-(exp(y(59))*exp(y(69))*params(90)/exp(y(66))));
  g1(75,66)=(-((-(exp(y(66))*exp(y(59))*exp(y(69))*params(90)))/(exp(y(66))*exp(y(66)))));
  g1(75,69)=(-(exp(y(59))*exp(y(69))*params(90)/exp(y(66))));
  g1(75,83)=exp(y(83));
  g1(76,59)=(-(T525*params(94)*T801));
  g1(76,67)=(-(T525*params(94)*(-(exp(y(67))*exp(y(59))*params(68)*exp(y(69))*(1-params(90))))/(exp(y(67))*exp(y(67)))));
  g1(76,69)=(-(T525*params(94)*T801));
  g1(76,83)=exp(y(83))-T525*params(94)*exp(y(83))*(1-params(91));
  g1(77,65)=1-params(86);
  g1(78,71)=1-(1+params(95)-params(96));
  g1(78,72)=params(95);
  g1(79,71)=(-exp(y(71)));
  g1(79,72)=exp(y(72));
  g1(80,73)=1-params(98);
  g1(81,74)=1-(1+params(100)-params(101));
  g1(81,75)=params(100);
  g1(82,74)=(-exp(y(74)));
  g1(82,75)=exp(y(75));
  g1(83,76)=1-(1+params(103)-params(104));
  g1(83,77)=params(103);
  g1(84,76)=(-exp(y(76)));
  g1(84,77)=exp(y(77));
  g1(85,78)=1-params(106);
  g1(86,79)=1-(1+params(108)-params(109));
  g1(86,80)=params(108);
  g1(87,79)=(-exp(y(79)));
  g1(87,80)=exp(y(80));
  g1(88,79)=(-exp(y(79)));
  g1(88,81)=exp(y(81));
  g1(89,104)=1-params(122);
  g1(90,108)=1-params(130);
  g1(91,85)=(-(exp(y(185))*exp(y(4))*exp(y(82))*(-params(111))*exp((-params(111))*y(85))/exp(y(82))/exp(y(4))/exp(y(185))));
  g1(92,29)=(-(exp(y(29))*params(171)));
  g1(92,35)=params(29)*params(188)*exp(y(35))*params(171);
  g1(92,68)=(-exp(y(68)));
  g1(92,74)=params(84)*params(189)*exp(y(74));
  g1(93,82)=(-T931);
  g1(93,83)=(-T931);
  g1(93,84)=exp(y(84));
  g1(93,184)=(-(exp(y(83))*T3523));
  g1(93,185)=(-T931);
  g1(94,23)=(-1);
  g1(94,85)=T936+y(85)*params(3)*T296*(-(T736*(-params(111))*exp((-params(111))*y(85))))/(exp((-params(111))*y(85))*exp((-params(111))*y(85)))/T296-1;
  g1(95,82)=(-T930);
  g1(95,86)=exp(y(86));
  g1(95,184)=(-T3523);
  g1(95,185)=(-T930);
  g1(96,82)=(-(exp(y(184))*(-exp(y(82)))/(exp(y(82))*exp(y(82)))/exp(y(185))));
  g1(96,87)=exp(y(87));
  g1(96,184)=(-T943);
  g1(96,185)=(-((-(exp(y(185))*exp(y(184))*1/exp(y(82))))/(exp(y(185))*exp(y(185)))));
  g1(97,86)=(-exp(y(86)));
  g1(97,96)=exp(y(96));
  g1(98,87)=(-exp(y(87)));
  g1(98,98)=exp(y(98));
  g1(99,50)=(-(exp(y(50))*T947));
  g1(99,54)=(-(exp(y(54))*T947));
  g1(99,97)=exp(y(97));
  g1(100,11)=(-(exp(y(11))*params(171)));
  g1(100,15)=(-(exp(y(15))*params(171)));
  g1(100,99)=exp(y(99));
  g1(101,32)=(-(exp(y(32))*exp(y(90))));
  g1(101,88)=exp(y(88));
  g1(101,90)=(-(exp(y(32))*exp(y(90))));
  g1(102,71)=(-(exp(y(71))*exp(y(90))));
  g1(102,89)=exp(y(89));
  g1(102,90)=(-(exp(y(71))*exp(y(90))));
  g1(103,90)=1-(1+params(114)-params(115));
  g1(103,91)=params(114);
  g1(104,90)=(-exp(y(90)));
  g1(104,91)=exp(y(91));
  g1(105,37)=(-(exp(y(37))*exp(y(94))));
  g1(105,92)=T140;
  g1(105,94)=(-(exp(y(37))*exp(y(94))));
  g1(106,76)=(-(exp(y(76))*exp(y(94))));
  g1(106,93)=T563;
  g1(106,94)=(-(exp(y(76))*exp(y(94))));
  g1(107,94)=1-(1+params(117)-params(118));
  g1(107,95)=params(117);
  g1(108,94)=(-exp(y(94)));
  g1(108,95)=exp(y(95));
  g1(109,39)=exp(y(39))*exp(y(114))*getPowerDeriv(T1000,(-1),1);
  g1(109,110)=(-(exp(y(110))*exp(y(181))));
  g1(109,114)=T1000*getPowerDeriv(T1000,(-1),1);
  g1(109,181)=(-(exp(y(110))*exp(y(181))));
  g1(110,110)=(-((-(exp(y(110))*params(161)*(1-exp(y(125)))^(-params(129))))/(exp(y(110))*exp(y(110)))));
  g1(110,125)=(-(params(161)*(-exp(y(125)))*getPowerDeriv(1-exp(y(125)),(-params(129)),1)/exp(y(110))));
  g1(110,179)=exp(y(179));
  g1(111,109)=(-((-((1+params(173))*params(137)*exp(y(109))))/((1+params(137)*exp(y(109)))*(1+params(137)*exp(y(109))))));
  g1(111,173)=(-(exp(y(179))*exp(y(173))))/(exp(y(173))*exp(y(173)));
  g1(111,179)=exp(y(179))/exp(y(173));
  g1(112,34)=(-(exp(y(34))*exp(y(111))));
  g1(112,111)=(-(exp(y(34))*exp(y(111))));
  g1(113,111)=exp(y(111))-T1058;
  g1(113,120)=(-(exp(y(124))*exp(y(110))*(-(T102*exp(y(120))))/(exp(y(120))*exp(y(120)))/exp(y(110))));
  g1(113,124)=(-T1053);
  g1(114,34)=(-(exp(y(34))*exp(y(112))));
  g1(114,112)=(-(exp(y(34))*exp(y(112))));
  g1(114,113)=exp(y(113))-(1-params(6))/params(3)*exp(y(113));
  g1(115,92)=T2675;
  g1(115,114)=exp(y(114));
  g1(115,115)=(-(getPowerDeriv(T1076,1+params(10),1)*T131*exp(y(115))*getPowerDeriv(exp(y(115)),T134,1)));
  g1(115,118)=T2675;
  g1(116,40)=(-(exp(y(117))^T156*params(165)*exp(y(40))*getPowerDeriv(params(165)*exp(y(40)),T152,1)*T2214));
  g1(116,115)=exp(y(115));
  g1(116,116)=(-(T2214*T153*exp(y(116))*getPowerDeriv(exp(y(116)),T156,1)));
  g1(116,117)=(-(T2214*T163*exp(y(117))*getPowerDeriv(exp(y(117)),T156,1)));
  g1(117,114)=T1096*exp(y(181))*T1091*getPowerDeriv(T1091,T130,1);
  g1(117,115)=T1096*T3042+T1093*T1095*getPowerDeriv(T1095,T152,1);
  g1(117,116)=T1093*getPowerDeriv(T1095,T152,1)*(-(exp(y(116))*params(164)*exp(y(115))))/(exp(y(116))*exp(y(116)));
  g1(117,181)=T1093*T1096;
  g1(118,40)=(-(T1093*T1102*getPowerDeriv(T1102,T152,1)));
  g1(118,114)=(-(T1102^T152*exp(y(181))*T1091*getPowerDeriv(T1091,T130,1)));
  g1(118,115)=(-(T1093*T1102*getPowerDeriv(T1102,T152,1)+T1102^T152*T3042));
  g1(118,117)=(-(T1093*getPowerDeriv(T1102,T152,1)*(-(exp(y(117))*params(165)*exp(y(40))*exp(y(115))))/(exp(y(117))*exp(y(117)))));
  g1(118,166)=exp(y(166));
  g1(118,181)=(-(T1093*T1102^T152));
  g1(119,92)=(-(T1113+T140*exp(y(181))*(-(T140*params(162)*exp(y(114))))/(T140*T140)/exp(y(118))*getPowerDeriv(T1110,T130,1)));
  g1(119,114)=(-(T140*exp(y(181))*T1110*getPowerDeriv(T1110,T130,1)));
  g1(119,118)=(-(T140*exp(y(181))*getPowerDeriv(T1110,T130,1)*(-(exp(y(118))*params(162)*exp(y(114))/T140))/(exp(y(118))*exp(y(118)))));
  g1(119,134)=exp(y(134));
  g1(119,181)=(-T1113);
  g1(120,42)=(-(exp(y(121))^T203*params(167)*exp(y(42))*getPowerDeriv(params(167)*exp(y(42)),T199,1)*T2228));
  g1(120,112)=exp(y(112));
  g1(120,119)=(-(T2228*T200*exp(y(119))*getPowerDeriv(exp(y(119)),T203,1)));
  g1(120,121)=(-(T2228*T210*exp(y(121))*getPowerDeriv(exp(y(121)),T203,1)));
  g1(121,112)=exp(y(120))*T1127*getPowerDeriv(T1127,T199,1);
  g1(121,119)=exp(y(120))*getPowerDeriv(T1127,T199,1)*(-(exp(y(119))*params(166)*exp(y(112))))/(exp(y(119))*exp(y(119)));
  g1(121,120)=exp(y(120))*T1127^T199;
  g1(122,42)=(-(exp(y(120))*T1134*getPowerDeriv(T1134,T199,1)));
  g1(122,112)=(-(exp(y(120))*T1134*getPowerDeriv(T1134,T199,1)));
  g1(122,120)=(-(exp(y(120))*T1134^T199));
  g1(122,121)=(-(exp(y(120))*getPowerDeriv(T1134,T199,1)*(-(exp(y(121))*params(167)*exp(y(42))*exp(y(112))))/(exp(y(121))*exp(y(121)))));
  g1(122,168)=exp(y(168));
  g1(123,88)=T2603;
  g1(123,113)=(-(getPowerDeriv(T1146,1+params(18),1)*T236*exp(y(113))/params(3)*getPowerDeriv(exp(y(113))/params(3),T238,1)));
  g1(123,122)=exp(y(122));
  g1(123,125)=T2603;
  g1(124,92)=T2691;
  g1(124,122)=(-(getPowerDeriv(T1158,1+params(10),1)*T254*exp(y(122))*getPowerDeriv(exp(y(122)),T134,1)));
  g1(124,123)=exp(y(123));
  g1(124,175)=T2691;
  g1(125,113)=(-(T1166*(-(exp(y(113))*params(3)*params(15)*exp(y(122))))/(exp(y(113))*exp(y(113)))*getPowerDeriv(T1169,T235,1)));
  g1(125,122)=(-(T1170*T3135+T1166*T1169*getPowerDeriv(T1169,T235,1)));
  g1(125,123)=(-(T1170*exp(y(177))*T1164*getPowerDeriv(T1164,T130,1)));
  g1(125,124)=exp(y(124));
  g1(125,177)=(-(T1166*T1170));
  g1(126,88)=(-(exp(y(88))*exp(y(173))))/(exp(y(88))*exp(y(88)))-T1166*(-(exp(y(88))*params(19)*exp(y(122))))/(exp(y(88))*exp(y(88)))/exp(y(125))*getPowerDeriv(T1176,T235,1);
  g1(126,122)=(-(T1176^T235*T3135+T1166*T1176*getPowerDeriv(T1176,T235,1)));
  g1(126,123)=(-(T1176^T235*exp(y(177))*T1164*getPowerDeriv(T1164,T130,1)));
  g1(126,125)=(-(T1166*getPowerDeriv(T1176,T235,1)*(-(exp(y(125))*params(19)*exp(y(122))/exp(y(88))))/(exp(y(125))*exp(y(125)))));
  g1(126,173)=exp(y(173))/exp(y(88));
  g1(126,177)=(-(T1166*T1176^T235));
  g1(127,92)=(-(T1185+T140*exp(y(177))*(-(T140*params(170)*exp(y(123))))/(T140*T140)/exp(y(175))*getPowerDeriv(T1182,T130,1)));
  g1(127,123)=(-(T140*exp(y(177))*T1182*getPowerDeriv(T1182,T130,1)));
  g1(127,134)=exp(y(134));
  g1(127,175)=(-(T140*exp(y(177))*getPowerDeriv(T1182,T130,1)*(-(exp(y(175))*params(170)*exp(y(123))/T140))/(exp(y(175))*exp(y(175)))));
  g1(127,177)=(-T1185);
  g1(128,105)=(-((-((1+params(174))*params(135)*exp(y(105))))/((1+params(135)*exp(y(105)))*(1+params(135)*exp(y(105))))));
  g1(128,177)=exp(y(177));
  g1(129,123)=exp(y(123));
  g1(129,222)=(-exp(y(222)));
  g1(130,116)=(-exp(y(116)));
  g1(130,119)=(-exp(y(119)));
  g1(130,130)=(-exp(y(130)));
  g1(130,169)=(-exp(y(169)));
  g1(130,222)=exp(y(222));
  g1(131,118)=(-exp(y(118)));
  g1(131,126)=exp(y(126));
  g1(131,175)=(-exp(y(175)));
  g1(132,127)=(-1)/((1+y(127))*(1+y(127)));
  g1(133,117)=(-(exp(y(117))*exp(y(166))));
  g1(133,121)=(-(exp(y(121))*exp(y(168))));
  g1(133,128)=exp(y(128));
  g1(133,166)=(-(exp(y(117))*exp(y(166))));
  g1(133,168)=(-(exp(y(121))*exp(y(168))));
  g1(134,35)=(-(params(29)*params(188)*exp(y(35))*exp(y(164))/exp(y(222))));
  g1(134,128)=(-((-exp(y(128)))/exp(y(222))));
  g1(134,129)=1;
  g1(134,133)=(-(exp(y(164))*(-exp(y(133)))/exp(y(222))));
  g1(134,164)=(-(exp(y(164))*(params(29)*params(188)*exp(y(35))-exp(y(133)))/exp(y(222))));
  g1(134,169)=(-(exp(y(169))/exp(y(222))));
  g1(134,222)=(-((-(exp(y(222))*(exp(y(169))-exp(y(128))+exp(y(164))*(params(29)*params(188)*exp(y(35))-exp(y(133))))))/(exp(y(222))*exp(y(222)))));
  g1(135,26)=(-(exp(y(26))*params(24)*exp(y(222))));
  g1(135,130)=exp(y(130));
  g1(135,222)=(-(exp(y(26))*params(24)*exp(y(222))));
  g1(136,126)=exp(y(126));
  g1(136,131)=(-(T1242*exp(y(131))*getPowerDeriv(exp(y(131)),params(35),1)));
  g1(136,132)=(-(exp(y(131))^params(35)*exp(y(132))/params(13)*getPowerDeriv(exp(y(132))/params(13),1-params(35),1)));
  g1(137,132)=exp(y(132))-(1-params(36))/params(13)*exp(y(132));
  g1(137,135)=(-exp(y(135)));
  g1(138,131)=(-exp(y(131)));
  g1(138,133)=exp(y(133));
  g1(138,135)=(-exp(y(135)));
  g1(139,126)=(-(exp(y(126))*params(35)*exp(y(134))/exp(y(131))));
  g1(139,131)=(-((-(exp(y(131))*exp(y(126))*params(35)*exp(y(134))))/(exp(y(131))*exp(y(131)))));
  g1(139,134)=(-(exp(y(126))*params(35)*exp(y(134))/exp(y(131))));
  g1(139,164)=exp(y(164));
  g1(140,126)=(-(T102*params(39)*T1259));
  g1(140,132)=(-(T102*params(39)*(-(exp(y(132))*exp(y(126))*params(13)*(1-params(35))*exp(y(134))))/(exp(y(132))*exp(y(132)))));
  g1(140,134)=(-(T102*params(39)*T1259));
  g1(140,164)=exp(y(164))-T102*params(39)*(1-params(36))*exp(y(164));
  g1(141,78)=exp(y(78))*exp(y(140))*getPowerDeriv(T1268,(-1),1);
  g1(141,136)=(-(exp(y(136))*exp(y(180))));
  g1(141,140)=T1268*getPowerDeriv(T1268,(-1),1);
  g1(141,180)=(-(exp(y(136))*exp(y(180))));
  g1(142,136)=(-((-(exp(y(136))*params(175)*(1-exp(y(151)))^(-params(127))))/(exp(y(136))*exp(y(136)))));
  g1(142,151)=(-(params(175)*(-exp(y(151)))*getPowerDeriv(1-exp(y(151)),(-params(127)),1)/exp(y(136))));
  g1(142,178)=exp(y(178));
  g1(143,108)=(-((-((1+params(186))*params(136)*exp(y(108))))/((1+params(136)*exp(y(108)))*(1+params(136)*exp(y(108))))));
  g1(143,172)=(-(exp(y(178))*exp(y(172))))/(exp(y(172))*exp(y(172)));
  g1(143,178)=exp(y(178))/exp(y(172));
  g1(144,73)=(-(exp(y(73))*exp(y(137))));
  g1(144,137)=(-(exp(y(73))*exp(y(137))));
  g1(145,137)=exp(y(137))-T1326;
  g1(145,146)=(-(exp(y(150))*exp(y(136))*(-(T525*exp(y(146))))/(exp(y(146))*exp(y(146)))/exp(y(136))));
  g1(145,150)=(-T1321);
  g1(146,73)=(-(exp(y(73))*exp(y(138))));
  g1(146,138)=(-(exp(y(73))*exp(y(138))));
  g1(146,139)=exp(y(139))-(1-params(61))/params(58)*exp(y(139));
  g1(147,93)=T2731;
  g1(147,140)=exp(y(140));
  g1(147,141)=(-(getPowerDeriv(T1344,1+params(65),1)*T554*exp(y(141))*getPowerDeriv(exp(y(141)),T557,1)));
  g1(147,144)=T2731;
  g1(148,79)=(-(exp(y(143))^T579*params(179)*exp(y(79))*getPowerDeriv(params(179)*exp(y(79)),T575,1)*T2529));
  g1(148,141)=exp(y(141));
  g1(148,142)=(-(T2529*T576*exp(y(142))*getPowerDeriv(exp(y(142)),T579,1)));
  g1(148,143)=(-(T2529*T586*exp(y(143))*getPowerDeriv(exp(y(143)),T579,1)));
  g1(149,140)=T1364*exp(y(180))*T1359*getPowerDeriv(T1359,T553,1);
  g1(149,141)=T1364*T3254+T1361*T1363*getPowerDeriv(T1363,T575,1);
  g1(149,142)=T1361*getPowerDeriv(T1363,T575,1)*(-(exp(y(142))*params(178)*exp(y(141))))/(exp(y(142))*exp(y(142)));
  g1(149,180)=T1361*T1364;
  g1(150,79)=(-(T1361*T1370*getPowerDeriv(T1370,T575,1)));
  g1(150,140)=(-(T1370^T575*exp(y(180))*T1359*getPowerDeriv(T1359,T553,1)));
  g1(150,141)=(-(T1361*T1370*getPowerDeriv(T1370,T575,1)+T1370^T575*T3254));
  g1(150,143)=(-(T1361*getPowerDeriv(T1370,T575,1)*(-(exp(y(143))*params(179)*exp(y(79))*exp(y(141))))/(exp(y(143))*exp(y(143)))));
  g1(150,167)=exp(y(167));
  g1(150,180)=(-(T1361*T1370^T575));
  g1(151,93)=(-(T1381+T563*exp(y(180))*(-(T563*params(176)*exp(y(140))))/(T563*T563)/exp(y(144))*getPowerDeriv(T1378,T553,1)));
  g1(151,140)=(-(T563*exp(y(180))*T1378*getPowerDeriv(T1378,T553,1)));
  g1(151,144)=(-(T563*exp(y(180))*getPowerDeriv(T1378,T553,1)*(-(exp(y(144))*params(176)*exp(y(140))/T563))/(exp(y(144))*exp(y(144)))));
  g1(151,160)=exp(y(160));
  g1(151,180)=(-T1381);
  g1(152,81)=(-(exp(y(147))^T626*params(181)*exp(y(81))*getPowerDeriv(params(181)*exp(y(81)),T622,1)*T2543));
  g1(152,138)=exp(y(138));
  g1(152,145)=(-(T2543*T623*exp(y(145))*getPowerDeriv(exp(y(145)),T626,1)));
  g1(152,147)=(-(T2543*T633*exp(y(147))*getPowerDeriv(exp(y(147)),T626,1)));
  g1(153,138)=exp(y(146))*T1395*getPowerDeriv(T1395,T622,1);
  g1(153,145)=exp(y(146))*getPowerDeriv(T1395,T622,1)*(-(exp(y(145))*params(180)*exp(y(138))))/(exp(y(145))*exp(y(145)));
  g1(153,146)=exp(y(146))*T1395^T622;
  g1(154,81)=(-(exp(y(146))*T1402*getPowerDeriv(T1402,T622,1)));
  g1(154,138)=(-(exp(y(146))*T1402*getPowerDeriv(T1402,T622,1)));
  g1(154,146)=(-(exp(y(146))*T1402^T622));
  g1(154,147)=(-(exp(y(146))*getPowerDeriv(T1402,T622,1)*(-(exp(y(147))*params(181)*exp(y(81))*exp(y(138))))/(exp(y(147))*exp(y(147)))));
  g1(154,170)=exp(y(170));
  g1(155,89)=T2631;
  g1(155,139)=(-(getPowerDeriv(T1414,1+params(73),1)*T659*exp(y(139))/params(58)*getPowerDeriv(exp(y(139))/params(58),T661,1)));
  g1(155,148)=exp(y(148));
  g1(155,151)=T2631;
  g1(156,93)=T2747;
  g1(156,148)=(-(getPowerDeriv(T1426,1+params(65),1)*T677*exp(y(148))*getPowerDeriv(exp(y(148)),T557,1)));
  g1(156,149)=exp(y(149));
  g1(156,174)=T2747;
  g1(157,139)=(-(T1434*(-(exp(y(139))*params(58)*params(70)*exp(y(148))))/(exp(y(139))*exp(y(139)))*getPowerDeriv(T1437,T658,1)));
  g1(157,148)=(-(T1438*T3347+T1434*T1437*getPowerDeriv(T1437,T658,1)));
  g1(157,149)=(-(T1438*exp(y(176))*T1432*getPowerDeriv(T1432,T553,1)));
  g1(157,150)=exp(y(150));
  g1(157,176)=(-(T1434*T1438));
  g1(158,89)=(-(exp(y(89))*exp(y(172))))/(exp(y(89))*exp(y(89)))-T1434*(-(exp(y(89))*params(74)*exp(y(148))))/(exp(y(89))*exp(y(89)))/exp(y(151))*getPowerDeriv(T1444,T658,1);
  g1(158,148)=(-(T1444^T658*T3347+T1434*T1444*getPowerDeriv(T1444,T658,1)));
  g1(158,149)=(-(T1444^T658*exp(y(176))*T1432*getPowerDeriv(T1432,T553,1)));
  g1(158,151)=(-(T1434*getPowerDeriv(T1444,T658,1)*(-(exp(y(151))*params(74)*exp(y(148))/exp(y(89))))/(exp(y(151))*exp(y(151)))));
  g1(158,172)=exp(y(172))/exp(y(89));
  g1(158,176)=(-(T1434*T1444^T658));
  g1(159,93)=(-(T1453+T563*exp(y(176))*(-(T563*params(184)*exp(y(149))))/(T563*T563)/exp(y(174))*getPowerDeriv(T1450,T553,1)));
  g1(159,149)=(-(T563*exp(y(176))*T1450*getPowerDeriv(T1450,T553,1)));
  g1(159,160)=exp(y(160));
  g1(159,174)=(-(T563*exp(y(176))*getPowerDeriv(T1450,T553,1)*(-(exp(y(174))*params(184)*exp(y(149))/T563))/(exp(y(174))*exp(y(174)))));
  g1(159,176)=(-T1453);
  g1(160,104)=(-((-((1+params(187))*params(134)*exp(y(104))))/((1+params(134)*exp(y(104)))*(1+params(134)*exp(y(104))))));
  g1(160,176)=exp(y(176));
  g1(161,149)=exp(y(149));
  g1(161,223)=(-exp(y(223)));
  g1(162,142)=(-exp(y(142)));
  g1(162,145)=(-exp(y(145)));
  g1(162,156)=(-exp(y(156)));
  g1(162,171)=(-exp(y(171)));
  g1(162,223)=exp(y(223));
  g1(163,144)=(-exp(y(144)));
  g1(163,152)=exp(y(152));
  g1(163,174)=(-exp(y(174)));
  g1(164,153)=(-1)/((1+y(153))*(1+y(153)));
  g1(165,143)=(-(exp(y(143))*exp(y(167))));
  g1(165,147)=(-(exp(y(147))*exp(y(170))));
  g1(165,154)=exp(y(154));
  g1(165,167)=(-(exp(y(143))*exp(y(167))));
  g1(165,170)=(-(exp(y(147))*exp(y(170))));
  g1(166,74)=(-(params(84)*params(189)*exp(y(74))*exp(y(163))/exp(y(223))));
  g1(166,154)=(-((-exp(y(154)))/exp(y(223))));
  g1(166,155)=1;
  g1(166,159)=(-(exp(y(163))*(-exp(y(159)))/exp(y(223))));
  g1(166,163)=(-(exp(y(163))*(params(84)*params(189)*exp(y(74))-exp(y(159)))/exp(y(223))));
  g1(166,171)=(-(exp(y(171))/exp(y(223))));
  g1(166,223)=(-((-(exp(y(223))*(exp(y(171))-exp(y(154))+exp(y(163))*(params(84)*params(189)*exp(y(74))-exp(y(159))))))/(exp(y(223))*exp(y(223)))));
  g1(167,65)=(-(exp(y(65))*params(79)*exp(y(223))));
  g1(167,156)=exp(y(156));
  g1(167,223)=(-(exp(y(65))*params(79)*exp(y(223))));
  g1(168,152)=exp(y(152));
  g1(168,157)=(-(T1510*exp(y(157))*getPowerDeriv(exp(y(157)),params(90),1)));
  g1(168,158)=(-(exp(y(157))^params(90)*exp(y(158))/params(68)*getPowerDeriv(exp(y(158))/params(68),1-params(90),1)));
  g1(169,158)=exp(y(158))-(1-params(91))/params(68)*exp(y(158));
  g1(169,161)=(-exp(y(161)));
  g1(170,157)=(-exp(y(157)));
  g1(170,159)=exp(y(159));
  g1(170,161)=(-exp(y(161)));
  g1(171,152)=(-(exp(y(152))*params(90)*exp(y(160))/exp(y(157))));
  g1(171,157)=(-((-(exp(y(157))*exp(y(152))*params(90)*exp(y(160))))/(exp(y(157))*exp(y(157)))));
  g1(171,160)=(-(exp(y(152))*params(90)*exp(y(160))/exp(y(157))));
  g1(171,163)=exp(y(163));
  g1(172,152)=(-(T525*params(94)*T1527));
  g1(172,158)=(-(T525*params(94)*(-(exp(y(158))*exp(y(152))*params(68)*(1-params(90))*exp(y(160))))/(exp(y(158))*exp(y(158)))));
  g1(172,160)=(-(T525*params(94)*T1527));
  g1(172,163)=exp(y(163))-T525*params(94)*(1-params(91))*exp(y(163));
  g1(173,165)=(-(exp(y(181))*exp(y(110))*exp(y(162))*(-params(111))*exp((-params(111))*y(165))/exp(y(162))/exp(y(110))/exp(y(181))));
  g1(174,35)=params(29)*params(188)*exp(y(35))*params(171);
  g1(174,74)=params(84)*params(189)*exp(y(74));
  g1(174,133)=(-(params(171)*exp(y(133))));
  g1(174,159)=(-exp(y(159)));
  g1(175,162)=(-T1549);
  g1(175,163)=(-T1549);
  g1(175,164)=exp(y(164));
  g1(175,180)=(-(exp(y(163))*T3497));
  g1(175,181)=(-T1549);
  g1(176,123)=T1555;
  g1(176,129)=(-1);
  g1(176,165)=T1554+y(165)*params(3)*exp(y(123))*(-(T1482*(-params(111))*exp((-params(111))*y(165))))/(exp((-params(111))*y(165))*exp((-params(111))*y(165)))/exp(y(222))-1;
  g1(176,222)=y(165)*params(3)*(-(exp(y(222))*exp(y(123))*T1482/exp((-params(111))*y(165))))/(exp(y(222))*exp(y(222)));
  g1(177,162)=(-T1548);
  g1(177,166)=exp(y(166));
  g1(177,180)=(-T3497);
  g1(177,181)=(-T1548);
  g1(178,162)=(-(exp(y(180))*(-exp(y(162)))/(exp(y(162))*exp(y(162)))/exp(y(181))));
  g1(178,167)=exp(y(167));
  g1(178,180)=(-T1561);
  g1(178,181)=(-((-(exp(y(181))*exp(y(180))*1/exp(y(162))))/(exp(y(181))*exp(y(181)))));
  g1(179,166)=(-exp(y(166)));
  g1(179,168)=exp(y(168));
  g1(180,167)=(-exp(y(167)));
  g1(180,170)=exp(y(170));
  g1(181,143)=(-(T947*exp(y(143))));
  g1(181,147)=(-(T947*exp(y(147))));
  g1(181,169)=exp(y(169));
  g1(182,117)=(-(params(171)*exp(y(117))));
  g1(182,121)=(-(params(171)*exp(y(121))));
  g1(182,171)=exp(y(171));
  g1(183,105)=(-(T296*exp(y(183))*T2867+exp(y(208))*T1579*T1585*T2874*log(T1582)));
  g1(183,183)=(-T1575);
  g1(183,208)=exp(y(208))-exp(y(208))*T1579*T1585;
  g1(183,211)=(-(exp(y(208))*T1579*T3729));
  g1(183,212)=(-(exp(y(208))*T1579*T3747));
  g1(183,220)=(-T1575);
  g1(184,105)=(-(T296*(-((1+params(174))*params(135)*exp(y(105))))/(params(135)*exp(y(105))*params(135)*exp(y(105)))+exp(y(209))*T1579*T1595*log(T1582)*(-T2867)));
  g1(184,209)=exp(y(209))-exp(y(209))*T1579*T1595;
  g1(184,211)=(-(exp(y(209))*T1579*T3727*T3733));
  g1(184,212)=(-(exp(y(209))*T1579*T3733*(-y(211))/(y(212)*y(212))));
  g1(184,220)=(-(T296*(1+params(174))/(params(135)*exp(y(105)))));
  g1(185,208)=(-(exp(y(208))/exp(y(209))));
  g1(185,209)=(-((-(exp(y(208))*exp(y(209))))/(exp(y(209))*exp(y(209)))));
  g1(185,210)=exp(y(210));
  g1(186,105)=(1-params(141))*T1606*T2891*log(exp(y(210)))+params(141)*T1608*log(T1582)*T2891;
  g1(186,210)=(1-params(141))*exp(y(210))*getPowerDeriv(exp(y(210)),T1605,1);
  g1(186,211)=params(141)*T3727*getPowerDeriv(T1582,T1605,1);
  g1(186,212)=params(141)*getPowerDeriv(T1582,T1605,1)*(-y(211))/(y(212)*y(212));
  g1(187,211)=1;
  g1(187,212)=(-(params(172)^(1-params(140))*getPowerDeriv(y(212),params(140),1)));
  g1(188,17)=exp(y(17));
  g1(188,213)=(-(T296*exp(y(213))));
  g1(188,220)=(-(T296*exp(y(213))));
  g1(189,105)=(-((1-params(141))*exp(y(210))^T1584*T2874*log(exp(y(210)))+exp(y(213))*params(141)*T1585*T2874*log(T1582)));
  g1(189,210)=(-((1-params(141))*exp(y(210))*getPowerDeriv(exp(y(210)),T1584,1)));
  g1(189,211)=(-(exp(y(213))*params(141)*T3729));
  g1(189,212)=(-(exp(y(213))*params(141)*T3747));
  g1(189,213)=exp(y(213))-exp(y(213))*params(141)*T1585;
  g1(190,187)=(-1);
  g1(190,212)=T3727;
  g1(191,104)=(-(exp(y(221))*exp(y(182))*T2818+exp(y(214))*T1642*T1648*T2825*log(T1645)));
  g1(191,182)=(-T1638);
  g1(191,214)=exp(y(214))-exp(y(214))*T1642*T1648;
  g1(191,217)=(-(exp(y(214))*T1642*T3793));
  g1(191,218)=(-(exp(y(214))*T1642*T3811));
  g1(191,221)=(-T1638);
  g1(192,104)=(-(exp(y(221))*(-((1+params(187))*params(134)*exp(y(104))))/(params(134)*exp(y(104))*params(134)*exp(y(104)))+exp(y(215))*T1642*T1658*log(T1645)*(-T2818)));
  g1(192,215)=exp(y(215))-exp(y(215))*T1642*T1658;
  g1(192,217)=(-(exp(y(215))*T1642*T3791*T3797));
  g1(192,218)=(-(exp(y(215))*T1642*T3797*(-y(217))/(y(218)*y(218))));
  g1(192,221)=(-(exp(y(221))*(1+params(187))/(params(134)*exp(y(104)))));
  g1(193,214)=(-(exp(y(214))/exp(y(215))));
  g1(193,215)=(-((-(exp(y(214))*exp(y(215))))/(exp(y(215))*exp(y(215)))));
  g1(193,216)=exp(y(216));
  g1(194,104)=(1-params(139))*T1669*T2842*log(exp(y(216)))+params(139)*T1671*log(T1645)*T2842;
  g1(194,216)=(1-params(139))*exp(y(216))*getPowerDeriv(exp(y(216)),T1668,1);
  g1(194,217)=params(139)*T3791*getPowerDeriv(T1645,T1668,1);
  g1(194,218)=params(139)*getPowerDeriv(T1645,T1668,1)*(-y(217))/(y(218)*y(218));
  g1(195,217)=1;
  g1(195,218)=(-(params(185)^(1-params(138))*getPowerDeriv(y(218),params(138),1)));
  g1(196,56)=exp(y(56));
  g1(196,219)=(-(exp(y(221))*exp(y(219))));
  g1(196,221)=(-(exp(y(221))*exp(y(219))));
  g1(197,104)=(-((1-params(139))*exp(y(216))^T1647*T2825*log(exp(y(216)))+exp(y(219))*params(139)*T1648*T2825*log(T1645)));
  g1(197,216)=(-((1-params(139))*exp(y(216))*getPowerDeriv(exp(y(216)),T1647,1)));
  g1(197,217)=(-(exp(y(219))*params(139)*T3793));
  g1(197,218)=(-(exp(y(219))*params(139)*T3811));
  g1(197,219)=exp(y(219))-exp(y(219))*params(139)*T1648;
  g1(198,186)=(-1);
  g1(198,218)=T3791;
  g1(199,19)=(-T1702);
  g1(199,101)=(-(exp(y(19))*(-(exp(y(101))*T1700))/(exp(y(101))*exp(y(101)))));
  g1(199,107)=(-T1702);
  g1(199,109)=(-(exp(y(19))*exp(y(107))*T2959/exp(y(101))+exp(y(198))*T1710*T1715*(params(137)*exp(y(109))*(-(params(137)*exp(y(109))))-params(137)*exp(y(109))*(-(1+params(137)*exp(y(109)))))/(params(137)*exp(y(109))*params(137)*exp(y(109)))*log(T1712)));
  g1(199,198)=exp(y(198))-exp(y(198))*T1710*T1715;
  g1(199,201)=(-(exp(y(198))*T1710*T3626*T3627));
  g1(199,202)=(-(exp(y(198))*(T1708*T1715+T1710*T3627*(-y(201))/(y(202)*y(202)))));
  g1(199,212)=(-(exp(y(198))*T1715*y(202)*(-T1707)/(y(212)*y(212))));
  g1(200,19)=(-(exp(y(19))*(1+params(173))/(params(137)*exp(y(109)))));
  g1(200,109)=(-(exp(y(19))*(-((1+params(173))*params(137)*exp(y(109))))/(params(137)*exp(y(109))*params(137)*exp(y(109)))+exp(y(199))*T1710*T1725*log(T1712)*(-T2959)));
  g1(200,199)=exp(y(199))-exp(y(199))*T1710*T1725;
  g1(200,201)=(-(exp(y(199))*T1710*T3626*T3632));
  g1(200,202)=(-(exp(y(199))*(T1708*T1725+T1710*T3632*(-y(201))/(y(202)*y(202)))));
  g1(200,212)=(-(exp(y(199))*T1725*y(202)*(-T1707)/(y(212)*y(212))));
  g1(201,101)=T2787;
  g1(201,198)=(-(exp(y(198))/exp(y(199))));
  g1(201,199)=(-((-(exp(y(198))*exp(y(199))))/(exp(y(199))*exp(y(199)))));
  g1(201,200)=T1732;
  g1(202,101)=(1-params(145))*T2787*getPowerDeriv(T1732,T1736,1);
  g1(202,109)=(1-params(145))*T1732^T1736*T2984*log(T1732)+params(145)*T1712^T1736*log(T1712)*T2984;
  g1(202,200)=(1-params(145))*T1732*getPowerDeriv(T1732,T1736,1);
  g1(202,201)=params(145)*T3626*getPowerDeriv(T1712,T1736,1);
  g1(202,202)=params(145)*getPowerDeriv(T1712,T1736,1)*(-y(201))/(y(202)*y(202));
  g1(203,201)=1;
  g1(203,202)=(-((params(3)*params(172))^(1-params(144))*getPowerDeriv(y(202),params(144),1)));
  g1(204,202)=1;
  g1(204,212)=(-params(3));
  g1(205,58)=(-T1757);
  g1(205,100)=(-(exp(y(58))*(-(exp(y(100))*T1755))/(exp(y(100))*exp(y(100)))));
  g1(205,106)=(-T1757);
  g1(205,108)=(-(exp(y(58))*exp(y(106))*T2916/exp(y(100))+exp(y(203))*T1765*T1770*(params(136)*exp(y(108))*(-(params(136)*exp(y(108))))-params(136)*exp(y(108))*(-(1+params(136)*exp(y(108)))))/(params(136)*exp(y(108))*params(136)*exp(y(108)))*log(T1767)));
  g1(205,203)=exp(y(203))-exp(y(203))*T1765*T1770;
  g1(205,206)=(-(exp(y(203))*T1765*1/y(207)*T3679));
  g1(205,207)=(-(exp(y(203))*(T1763*T1770+T1765*T3679*(-y(206))/(y(207)*y(207)))));
  g1(205,218)=(-(exp(y(203))*T1770*y(207)*(-T1762)/(y(218)*y(218))));
  g1(206,58)=(-(exp(y(58))*(1+params(186))/(params(136)*exp(y(108)))));
  g1(206,108)=(-(exp(y(58))*(-((1+params(186))*params(136)*exp(y(108))))/(params(136)*exp(y(108))*params(136)*exp(y(108)))+exp(y(204))*T1765*T1780*log(T1767)*(-T2916)));
  g1(206,204)=exp(y(204))-exp(y(204))*T1765*T1780;
  g1(206,206)=(-(exp(y(204))*T1765*1/y(207)*T3684));
  g1(206,207)=(-(exp(y(204))*(T1763*T1780+T1765*T3684*(-y(206))/(y(207)*y(207)))));
  g1(206,218)=(-(exp(y(204))*T1780*y(207)*(-T1762)/(y(218)*y(218))));
  g1(207,100)=T2775;
  g1(207,203)=(-(exp(y(203))/exp(y(204))));
  g1(207,204)=(-((-(exp(y(203))*exp(y(204))))/(exp(y(204))*exp(y(204)))));
  g1(207,205)=T1787;
  g1(208,100)=(1-params(143))*T2775*getPowerDeriv(T1787,T1791,1);
  g1(208,108)=(1-params(143))*T1787^T1791*T2941*log(T1787)+params(143)*T1767^T1791*log(T1767)*T2941;
  g1(208,205)=(1-params(143))*T1787*getPowerDeriv(T1787,T1791,1);
  g1(208,206)=params(143)*1/y(207)*getPowerDeriv(T1767,T1791,1);
  g1(208,207)=params(143)*getPowerDeriv(T1767,T1791,1)*(-y(206))/(y(207)*y(207));
  g1(209,206)=1;
  g1(209,207)=(-((params(58)*params(185))^(1-params(142))*getPowerDeriv(y(207),params(142),1)));
  g1(210,207)=1;
  g1(210,218)=(-params(58));
  g1(211,189)=(-(T1851*T1813*T1839*T1831*T1823*(T1819*1/(1+log(params(172)))+T1817*1/(1+log(params(172)))*getPowerDeriv(T1817,params(149),1))*T3567));
  g1(211,191)=(-(T1851*T1813*T3567*T1839*T1817*T1819*T1823*1/(1+log(params(172))+log(params(39)))*getPowerDeriv(T1829,params(152),1)));
  g1(211,194)=1/(1+params(190))-T1851*(T1817*T1819*T1823*T1831*T1839)^(1-params(146))*1/(1+params(190))*getPowerDeriv((1+y(194))/(1+params(190)),params(146),1);
  g1(211,196)=(-(T1813*(T1817*T1819*T1823*T1831*T1839)^(1-params(146))*(-1)/((1+y(196))*(1+y(196)))*getPowerDeriv(1/(1+y(196)),params(150),1)*getPowerDeriv(T1848,1-params(148),1)));
  g1(211,202)=(-(T1851*T1813*T3567*T1817*T1819*T1823*T1831*T3626/(1+log(params(172))+log(params(3)))*getPowerDeriv(T1837,params(147),1)));
  g1(211,220)=(-(T1851*T1813*T3567*T1839*T1831*T1817*T1819*T1821*getPowerDeriv(T1821,params(151),1)));
  g1(211,222)=(-(T1851*T1813*T3567*T1839*T1831*T1817*T1819*getPowerDeriv(T1821,params(151),1)*(-(T296*exp(y(222))))/(exp(y(222))*exp(y(222)))));
  g1(212,3)=1;
  g1(212,220)=(-T1821);
  g1(212,222)=(-((-(T296*exp(y(222))))/(exp(y(222))*exp(y(222)))));
  g1(213,187)=(-((-T313)/((1+y(187))*(1+y(187)))));
  g1(213,194)=(-1)/((1+y(194))*(1+y(194)));
  g1(214,8)=(-T1960);
  g1(214,9)=(-T1981);
  g1(214,185)=(-T174);
  g1(214,193)=exp(y(193));
  g1(215,189)=1;
  g1(215,212)=(-T3727);
  g1(216,190)=1;
  g1(216,212)=(-T3727);
  g1(217,191)=1;
  g1(217,212)=(-T3727);
  g1(218,196)=1-params(157);
  g1(219,188)=(-(T1881*T1895*(T1891*1/(1+log(params(185)))+T1885*1/T1888*getPowerDeriv(T1889,params(154),1))*T3554));
  g1(219,195)=1/(1+params(191))-T1898*1/(1+params(191))*getPowerDeriv((1+y(195))/(1+params(191)),params(153),1);
  g1(219,197)=(-(T1881*T3554*T1895*T1885*getPowerDeriv(T1889,params(154),1)*(-((1+y(188))*(1+log(params(185)))))/(T1888*T1888)));
  g1(219,221)=(-(T1881*T3554*T1885*T1891*T1893*getPowerDeriv(T1893,params(156),1)));
  g1(219,223)=(-(T1881*T3554*T1885*T1891*getPowerDeriv(T1893,params(156),1)*(-(exp(y(221))*exp(y(223))))/(exp(y(223))*exp(y(223)))));
  g1(220,186)=(-((-T736)/((1+y(186))*(1+y(186)))));
  g1(220,195)=(-1)/((1+y(195))*(1+y(195)));
  g1(221,47)=(-T2276);
  g1(221,48)=(-T2297);
  g1(221,184)=(-T597);
  g1(221,192)=exp(y(192));
  g1(222,188)=1;
  g1(222,218)=(-T3791);
  g1(223,197)=1-params(159);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],223,49729);
end
end
